<?php

defined( 'ABSPATH' ) || exit; // Exit if accessed directly

if ( ! class_exists( 'KANEWS_CATEGORY' ) ) {

  class KANEWS_CATEGORY {

    function __construct() {

      add_action( 'category_add_form_fields', array ( $this, 'create_category_fields' ), 10, 2 );
      add_action( 'created_category', array ( $this, 'save_category_fields' ), 10, 2 );
      add_action( 'category_edit_form_fields', array ( $this, 'edit_category_fields' ), 10, 2 );
      add_action( 'edited_category', array ( $this, 'updated_category_fields' ), 10, 2 );

      add_action( 'admin_enqueue_scripts', array( $this, 'admin_add_scripts' ) );
      add_action( 'admin_footer', array( $this, 'admin_print_scripts' ) );
    }

    /**
		* Enqueue Scripts
		*
		* @since 1.0.0
		*/
    function admin_add_scripts() {
      wp_enqueue_media();
      wp_enqueue_script( 'wp-color-picker' );
	    wp_enqueue_style( 'wp-color-picker' );
    }

    /**
		* Print Script
		*
		* @since 1.0.0
		*/
    function admin_print_scripts() { ?>
      <script>
        jQuery( document ).ready( function( $ ) {
          $( '.colorpicker' ).wpColorPicker();
        } );
      </script>
      <script>
        jQuery(document).ready( function($) {
          function ct_media_upload(button_class) {
            var _custom_media = true,
            _orig_send_attachment = wp.media.editor.send.attachment;
            $('body').on('click', button_class, function(e) {
              var button_id = '#'+$(this).attr('id');
              var send_attachment_bkp = wp.media.editor.send.attachment;
              var button = $(button_id);
              _custom_media = true;
              wp.media.editor.send.attachment = function(props, attachment){
                if ( _custom_media ) {
                  $('#category-image-id').val(attachment.id);
                  $('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
                  $('#category-image-wrapper .custom_media_image').attr('src',attachment.url).css('display','block');
                } else {
                  return _orig_send_attachment.apply( button_id, [props, attachment] );
                }
              }
              wp.media.editor.open(button);
              return false;
            });
          }
          ct_media_upload('.ct_tax_media_button.button'); 
          $('body').on('click','.ct_tax_media_remove',function(){
            $('#category-image-id').val('');
            $('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
          });
          $(document).ajaxComplete(function(event, xhr, settings) {
            var queryStringArr = settings.data.split('&');
            if( $.inArray('action=add-tag', queryStringArr) !== -1 ){
              var xml = xhr.responseXML;
              $response = $(xml).find('term_id').text();
              if($response!=""){
                $('#category-image-wrapper').html('');
              }
            }
          });
        });
      </script>
    <?php }

    /**
		* Add a form field in the new category page
		*
		* @since 1.0.0
		*/
    function create_category_fields($taxonomy) { ?>
      <div class="form-field term-group">
        <label for="category-image-id"><?php _e('Kategori Görseli', 'kanews-admin'); ?></label>
        <input type="hidden" id="category-image-id" name="category-image-id" class="custom_media_url" value="">
        <div id="category-image-wrapper"></div>
        <p>
          <input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Görsel Ekle', 'kanews-admin' ); ?>" />
          <input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Görseli Kaldır', 'kanews-admin' ); ?>" />
        </p>
      </div>
      <div class="form-field term-group">
        <label for="category-posts-per-page"><?php _e('Gösterilecek Yazı Sayısı', 'kanews-admin'); ?></label>
        <input type="number" min="1" step="1" id="category-posts-per-page" name="category-posts-per-page" class="custom_media_url" value="">
      </div>
      
    <?php }

    /**
		* Add a form field in the new category edit page
		*
		* @since 1.0.0
		*/
    function edit_category_fields($term, $taxonomy ) { 
      $posts = get_term_meta( $term->term_id, 'category-posts-per-page', true );
      $color = get_term_meta( $term->term_id, '_category_color', true );
	    $color = ( ! empty( $color ) ) ? "#{$color}" : '';
      ?>
      <tr class="form-field term-group-wrap">
        <th scope="row">
          <label for="category-image-id"><?php _e( 'Görsel', 'kanews-admin' ); ?> (155x230px)</label>
        </th>
        <td>
          <?php $image_id = get_term_meta ( $term -> term_id, 'category-image-id', true ); ?>
          <input type="hidden" id="category-image-id" name="category-image-id" value="<?php echo $image_id; ?>">
          <div id="category-image-wrapper">
            <?php if ( $image_id ) { ?>
              <?php echo wp_get_attachment_image ( $image_id, 'kanews-post-6' ); ?>
            <?php } ?>
          </div>
          <p>
            <input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Görsel Ekle', 'kanews-admin' ); ?>" />
            <input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Görsel Kaldır', 'kanews-admin' ); ?>" />
          </p>
        </td>
      </tr>
      <tr class="form-field term-colorpicker-wrap">
        <th scope="row"><label for="term-colorpicker"><?php _e('Kategori Rengi', 'kanewsit-admin'); ?></label></th>
        <td>
          <input name="_category_color" value="<?php echo $color; ?>" class="colorpicker" id="term-colorpicker" />
        </td>
      </tr>
      <tr class="form-field">
        <th scope="row"><label for="category-posts-per-page"><?php _e('Gösterilecek Yazı Sayısı', 'kanewsit-admin'); ?></label></th>
        <td>
          <input name="category-posts-per-page" value="<?php echo $posts; ?>" id="category-posts-per-page" type="number" min="1" step="1"  />
        </td>
      </tr>
    <?php }

    /**
		* Save the form field
		*
		* @since 1.0.0
    */
    function save_category_fields ( $term_id, $tt_id ) {
      if( isset( $_POST['category-posts-per-page'] ) && '' !== $_POST['category-posts-per-page'] ){
        $posts = $_POST['category-posts-per-page'];
        add_term_meta( $term_id, 'category-posts-per-page', $posts, true );
      }
      if( isset( $_POST['category-image-id'] ) && '' !== $_POST['category-image-id'] ){
        $image = $_POST['category-image-id'];
        add_term_meta( $term_id, 'category-image-id', $image, true );
      }
      if( isset( $_POST['_category_color'] ) && ! empty( $_POST['_category_color'] ) ) {
        update_term_meta( $term_id, '_category_color', sanitize_hex_color_no_hash( $_POST['_category_color'] ) );
      } else {
        delete_term_meta( $term_id, '_category_color' );
      }
    }

    /**
		* Update the form field value
		*
		* @since 1.0.0
		*/
    function updated_category_fields ( $term_id, $tt_id ) {
      if( isset( $_POST['category-image-id'] ) && '' !== $_POST['category-image-id'] ){
        $image = $_POST['category-image-id'];
        update_term_meta ( $term_id, 'category-image-id', $image );
      } else {
        update_term_meta ( $term_id, 'category-image-id', '' );
      }
      if( isset( $_POST['category-posts-per-page'] ) && '' !== $_POST['category-posts-per-page'] ){
        $posts = $_POST['category-posts-per-page'];
        update_term_meta ( $term_id, 'category-posts-per-page', $posts );
      } else {
        update_term_meta ( $term_id, 'category-posts-per-page', '' );
      }
      if( isset( $_POST['_category_color'] ) && ! empty( $_POST['_category_color'] ) ) {
        update_term_meta( $term_id, '_category_color', sanitize_hex_color_no_hash( $_POST['_category_color'] ) );
      } else {
        delete_term_meta( $term_id, '_category_color' );
      }
    }
  

  }
  
  $KANEWS_CATEGORY = new KANEWS_CATEGORY();
}