<?php

defined( 'ABSPATH' ) || exit; // Exit if accessed directly

if( ! class_exists( 'KANEWS_HOOK' ) ) {

	class KANEWS_HOOK {

		function __construct() {
      
      // Scripts
      add_action( 'admin_enqueue_scripts', 'KANEWS_HELPER::admin_scripts' );
      add_action( 'wp_enqueue_scripts', 'KANEWS_WP_HELPER::woocommerce_styles', 99 );
      if(!is_singular() && kanews_get_option('emoji') == true) {
        remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
      }

      // Main
      add_action( 'kanews_footer', 'kanews_login_modal', 10 );
      add_action( 'kanews_footer', 'kanews_mobile_menu', 10 );
      add_filter( 'body_class', 'KANEWS_HELPER::body_classes' );
      add_filter( 'wp_footer', 'KANEWS_HELPER::back_to_top' );
      add_filter( 'kanews_footer', 'KANEWS_HELPER::wp_footer', 5 );
      add_filter( 'wp_head', 'KANEWS_HELPER::wp_head' );
      add_filter( 'wp_head', 'KANEWS_WP_HELPER::dns_prefetch' );
      add_filter( 'wp_head', 'KANEWS_WP_HELPER::weather_dns_prefetch' );
      add_filter( 'wp_calculate_image_srcset', 'KANEWS_WP_HELPER::disable_srcset' );
      add_filter( 'init', 'KANEWS_WP_HELPER::comments_order_reverse_parameter' );
      add_action( 'wp', 'KANEWS_BREADCRUMBS::instance' );

      // Post
      add_action( 'kanews_post_hook', 'kanews_add_bookmark', 5 );
      add_action( 'kanews_post_hook', 'kanews_video_time', 10 );
      add_action( 'kanews_entry_above', 'kanews_link_pages_after', 5 );
      add_filter( 'excerpt_more', 'KANEWS_WP_HELPER::excerpt_more' );
      add_filter( 'excerpt_length', 'KANEWS_HELPER::excerpt_length', 999 );
      add_filter( 'the_tags', 'KANEWS_WP_HELPER::the_tags' );
      add_action( 'kanews_entry_above', 'kanews_like_button', 10, 1 );
      add_action( 'kanews_entry_above', 'kanews_post_tags', 15, 1 );
      add_action( 'navigation_markup_template', 'KANEWS_WP_HELPER::sanitize_pagination' );
      add_action( 'init', 'add_post_types_support', 15 );
      add_action( 'get_comment_author', 'KANEWS_WP_HELPER::update_author_nickname', 15 );

      // lazy
      add_filter( 'the_content', 'add_image_placeholders', 99 );
      add_filter( 'wp_get_attachment_image_attributes', 'wpse8170_add_lazyload_to_attachment_image', 10, 2 );

      // covid
      wp_clear_scheduled_hook( 'kanews_covid' );

      // archives
      add_action( 'pre_get_posts', 'KANEWS_WP_HELPER::cat_posts_per_page' );
    }
    
  }
  
  $KANEWS_HOOK = new KANEWS_HOOK();
}




/*-----------------------------------------------------------------------------------*/
# Google Fonts
/*-----------------------------------------------------------------------------------*/
if( ! class_exists( 'KANEWS_GOOGLE_FONTS' ) ) {
	class KANEWS_GOOGLE_FONTS {
		function __construct() {
			add_filter('switch_theme', array($this, 'clear_schedules'));
			add_filter('cron_schedules', array( $this, 'cron_schedules' ));

			add_action( 'kanews_google_fonts_update', array($this, 'update_fonts') );
			if ( !wp_next_scheduled( 'kanews_google_fonts_update' ) ) {
				wp_schedule_event( time(), 'kanews_monthly', 'kanews_google_fonts_update' );
			}
		}
		function clear_schedules() {
			wp_clear_scheduled_hook( 'kanews_google_fonts_update' );
		}
		function cron_schedules( $schedules ) {
      $schedules['kanews_monthly'] = array(
        'interval' => 2592000,
        'display' => __('Ayda bir', 'kanews')
      );
      return $schedules;
    }
		function update_fonts() {
			$google_api_anahtari = "AIzaSyB0-O9pGI7tVkN3_8EuzrD3lJcn1O8xdSg";
			$curl = curl_init();
			curl_setopt($curl, CURLOPT_URL, 'https://www.googleapis.com/webfonts/v1/webfonts?key='.$google_api_anahtari);
			curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, FALSE);    
			$fonts = json_decode(curl_exec($curl), true);
			$http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
			curl_close($curl);
			if($http_code != 200){
				return;
			} else {
				 update_option('kanews_google_fonts', $fonts['items']);
			}
		}
	}
	$fonts = new KANEWS_GOOGLE_FONTS();
}

function kanews_google_fonts() {
	$fonts = get_option('kanews_google_fonts');

	if($fonts == ''){
    $list = array( "abeezee" => "ABeeZee", "abel" => "Abel", "abhaya_libre" => "Abhaya Libre", "abril_fatface" => "Abril Fatface", "aclonica" => "Aclonica", "acme" => "Acme", "actor" => "Actor", "adamina" => "Adamina", "advent_pro" => "Advent Pro", "aguafina_script" => "Aguafina Script", "akronim" => "Akronim", "aladin" => "Aladin", "alata" => "Alata", "alatsi" => "Alatsi", "aldrich" => "Aldrich", "alef" => "Alef", "alegreya" => "Alegreya", "alegreya_sc" => "Alegreya SC", "alegreya_sans" => "Alegreya Sans", "alegreya_sans_sc" => "Alegreya Sans SC", "aleo" => "Aleo", "alex_brush" => "Alex Brush", "alfa_slab_one" => "Alfa Slab One", "alice" => "Alice", "alike" => "Alike", "alike_angular" => "Alike Angular", "allan" => "Allan", "allerta" => "Allerta", "allerta_stencil" => "Allerta Stencil", "allura" => "Allura", "almarai" => "Almarai", "almendra" => "Almendra", "almendra_display" => "Almendra Display", "almendra_sc" => "Almendra SC", "amarante" => "Amarante", "amaranth" => "Amaranth", "amatic_sc" => "Amatic SC", "amethysta" => "Amethysta", "amiko" => "Amiko", "amiri" => "Amiri", "amita" => "Amita", "anaheim" => "Anaheim", "andada" => "Andada", "andika" => "Andika", "andika_new_basic" => "Andika New Basic", "angkor" => "Angkor", "annie_use_your_telescope" => "Annie Use Your Telescope", "anonymous_pro" => "Anonymous Pro", "antic" => "Antic", "antic_didone" => "Antic Didone", "antic_slab" => "Antic Slab", "anton" => "Anton", "arapey" => "Arapey", "arbutus" => "Arbutus", "arbutus_slab" => "Arbutus Slab", "architects_daughter" => "Architects Daughter", "archivo" => "Archivo", "archivo_black" => "Archivo Black", "archivo_narrow" => "Archivo Narrow", "aref_ruqaa" => "Aref Ruqaa", "arima_madurai" => "Arima Madurai", "arimo" => "Arimo", "arizonia" => "Arizonia", "armata" => "Armata", "arsenal" => "Arsenal", "artifika" => "Artifika", "arvo" => "Arvo", "arya" => "Arya", "asap" => "Asap", "asap_condensed" => "Asap Condensed", "asar" => "Asar", "asset" => "Asset", "assistant" => "Assistant", "astloch" => "Astloch", "asul" => "Asul", "athiti" => "Athiti", "atma" => "Atma", "atomic_age" => "Atomic Age", "aubrey" => "Aubrey", "audiowide" => "Audiowide", "autour_one" => "Autour One", "average" => "Average", "average_sans" => "Average Sans", "averia_gruesa_libre" => "Averia Gruesa Libre", "averia_libre" => "Averia Libre", "averia_sans_libre" => "Averia Sans Libre", "averia_serif_libre" => "Averia Serif Libre", "b612" => "B612", "b612_mono" => "B612 Mono", "bad_script" => "Bad Script", "bahiana" => "Bahiana", "bahianita" => "Bahianita", "bai_jamjuree" => "Bai Jamjuree", "baloo_2" => "Baloo 2", "baloo_bhai_2" => "Baloo Bhai 2", "baloo_bhaina_2" => "Baloo Bhaina 2", "baloo_chettan_2" => "Baloo Chettan 2", "baloo_da_2" => "Baloo Da 2", "baloo_paaji_2" => "Baloo Paaji 2", "baloo_tamma_2" => "Baloo Tamma 2", "baloo_tammudu_2" => "Baloo Tammudu 2", "baloo_thambi_2" => "Baloo Thambi 2", "balsamiq_sans" => "Balsamiq Sans", "balthazar" => "Balthazar", "bangers" => "Bangers", "barlow" => "Barlow", "barlow_condensed" => "Barlow Condensed", "barlow_semi_condensed" => "Barlow Semi Condensed", "barriecito" => "Barriecito", "barrio" => "Barrio", "basic" => "Basic", "baskervville" => "Baskervville", "battambang" => "Battambang", "baumans" => "Baumans", "bayon" => "Bayon", "be_vietnam" => "Be Vietnam", "bebas_neue" => "Bebas Neue", "belgrano" => "Belgrano", "bellefair" => "Bellefair", "belleza" => "Belleza", "bellota" => "Bellota", "bellota_text" => "Bellota Text", "benchnine" => "BenchNine", "bentham" => "Bentham", "berkshire_swash" => "Berkshire Swash", "beth_ellen" => "Beth Ellen", "bevan" => "Bevan", "big_shoulders_display" => "Big Shoulders Display", "big_shoulders_inline_display" => "Big Shoulders Inline Display", "big_shoulders_inline_text" => "Big Shoulders Inline Text", "big_shoulders_stencil_display" => "Big Shoulders Stencil Display", "big_shoulders_stencil_text" => "Big Shoulders Stencil Text", "big_shoulders_text" => "Big Shoulders Text", "bigelow_rules" => "Bigelow Rules", "bigshot_one" => "Bigshot One", "bilbo" => "Bilbo", "bilbo_swash_caps" => "Bilbo Swash Caps", "biorhyme" => "BioRhyme", "biorhyme_expanded" => "BioRhyme Expanded", "biryani" => "Biryani", "bitter" => "Bitter", "black_and_white_picture" => "Black And White Picture", "black_han_sans" => "Black Han Sans", "black_ops_one" => "Black Ops One", "blinker" => "Blinker", "bokor" => "Bokor", "bonbon" => "Bonbon", "boogaloo" => "Boogaloo", "bowlby_one" => "Bowlby One", "bowlby_one_sc" => "Bowlby One SC", "brawler" => "Brawler", "bree_serif" => "Bree Serif", "bubblegum_sans" => "Bubblegum Sans", "bubbler_one" => "Bubbler One", "buda" => "Buda", "buenard" => "Buenard", "bungee" => "Bungee", "bungee_hairline" => "Bungee Hairline", "bungee_inline" => "Bungee Inline", "bungee_outline" => "Bungee Outline", "bungee_shade" => "Bungee Shade", "butcherman" => "Butcherman", "butterfly_kids" => "Butterfly Kids", "cabin" => "Cabin", "cabin_condensed" => "Cabin Condensed", "cabin_sketch" => "Cabin Sketch", "caesar_dressing" => "Caesar Dressing", "cagliostro" => "Cagliostro", "cairo" => "Cairo", "caladea" => "Caladea", "calistoga" => "Calistoga", "calligraffitti" => "Calligraffitti", "cambay" => "Cambay", "cambo" => "Cambo", "candal" => "Candal", "cantarell" => "Cantarell", "cantata_one" => "Cantata One", "cantora_one" => "Cantora One", "capriola" => "Capriola", "cardo" => "Cardo", "carme" => "Carme", "carrois_gothic" => "Carrois Gothic", "carrois_gothic_sc" => "Carrois Gothic SC", "carter_one" => "Carter One", "castoro" => "Castoro", "catamaran" => "Catamaran", "caudex" => "Caudex", "caveat" => "Caveat", "caveat_brush" => "Caveat Brush", "cedarville_cursive" => "Cedarville Cursive", "ceviche_one" => "Ceviche One", "chakra_petch" => "Chakra Petch", "changa" => "Changa", "changa_one" => "Changa One", "chango" => "Chango", "charm" => "Charm", "charmonman" => "Charmonman", "chathura" => "Chathura", "chau_philomene_one" => "Chau Philomene One", "chela_one" => "Chela One", "chelsea_market" => "Chelsea Market", "chenla" => "Chenla", "cherry_cream_soda" => "Cherry Cream Soda", "cherry_swash" => "Cherry Swash", "chewy" => "Chewy", "chicle" => "Chicle", "chilanka" => "Chilanka", "chivo" => "Chivo", "chonburi" => "Chonburi", "cinzel" => "Cinzel", "cinzel_decorative" => "Cinzel Decorative", "clicker_script" => "Clicker Script", "coda" => "Coda", "coda_caption" => "Coda Caption", "codystar" => "Codystar", "coiny" => "Coiny", "combo" => "Combo", "comfortaa" => "Comfortaa", "comic_neue" => "Comic Neue", "coming_soon" => "Coming Soon", "commissioner" => "Commissioner", "concert_one" => "Concert One", "condiment" => "Condiment", "content" => "Content", "contrail_one" => "Contrail One", "convergence" => "Convergence", "cookie" => "Cookie", "copse" => "Copse", "corben" => "Corben", "cormorant" => "Cormorant", "cormorant_garamond" => "Cormorant Garamond", "cormorant_infant" => "Cormorant Infant", "cormorant_sc" => "Cormorant SC", "cormorant_unicase" => "Cormorant Unicase", "cormorant_upright" => "Cormorant Upright", "courgette" => "Courgette", "courier_prime" => "Courier Prime", "cousine" => "Cousine", "coustard" => "Coustard", "covered_by_your_grace" => "Covered By Your Grace", "crafty_girls" => "Crafty Girls", "creepster" => "Creepster", "crete_round" => "Crete Round", "crimson_pro" => "Crimson Pro", "crimson_text" => "Crimson Text", "croissant_one" => "Croissant One", "crushed" => "Crushed", "cuprum" => "Cuprum", "cute_font" => "Cute Font", "cutive" => "Cutive", "cutive_mono" => "Cutive Mono", "dm_mono" => "DM Mono", "dm_sans" => "DM Sans", "dm_serif_display" => "DM Serif Display", "dm_serif_text" => "DM Serif Text", "damion" => "Damion", "dancing_script" => "Dancing Script", "dangrek" => "Dangrek", "darker_grotesque" => "Darker Grotesque", "david_libre" => "David Libre", "dawning_of_a_new_day" => "Dawning of a New Day", "days_one" => "Days One", "dekko" => "Dekko", "delius" => "Delius", "delius_swash_caps" => "Delius Swash Caps", "delius_unicase" => "Delius Unicase", "della_respira" => "Della Respira", "denk_one" => "Denk One", "devonshire" => "Devonshire", "dhurjati" => "Dhurjati", "didact_gothic" => "Didact Gothic", "diplomata" => "Diplomata", "diplomata_sc" => "Diplomata SC", "do_hyeon" => "Do Hyeon", "dokdo" => "Dokdo", "domine" => "Domine", "donegal_one" => "Donegal One", "doppio_one" => "Doppio One", "dorsa" => "Dorsa", "dosis" => "Dosis", "dr_sugiyama" => "Dr Sugiyama", "duru_sans" => "Duru Sans", "dynalight" => "Dynalight", "eb_garamond" => "EB Garamond", "eagle_lake" => "Eagle Lake", "east_sea_dokdo" => "East Sea Dokdo", "eater" => "Eater", "economica" => "Economica", "eczar" => "Eczar", "el_messiri" => "El Messiri", "electrolize" => "Electrolize", "elsie" => "Elsie", "elsie_swash_caps" => "Elsie Swash Caps", "emblema_one" => "Emblema One", "emilys_candy" => "Emilys Candy", "encode_sans" => "Encode Sans", "encode_sans_condensed" => "Encode Sans Condensed", "encode_sans_expanded" => "Encode Sans Expanded", "encode_sans_semi_condensed" => "Encode Sans Semi Condensed", "encode_sans_semi_expanded" => "Encode Sans Semi Expanded", "engagement" => "Engagement", "englebert" => "Englebert", "enriqueta" => "Enriqueta", "epilogue" => "Epilogue", "erica_one" => "Erica One", "esteban" => "Esteban", "euphoria_script" => "Euphoria Script", "ewert" => "Ewert", "exo" => "Exo", "exo_2" => "Exo 2", "expletus_sans" => "Expletus Sans", "fahkwang" => "Fahkwang", "fanwood_text" => "Fanwood Text", "farro" => "Farro", "farsan" => "Farsan", "fascinate" => "Fascinate", "fascinate_inline" => "Fascinate Inline", "faster_one" => "Faster One", "fasthand" => "Fasthand", "fauna_one" => "Fauna One", "faustina" => "Faustina", "federant" => "Federant", "federo" => "Federo", "felipa" => "Felipa", "fenix" => "Fenix", "finger_paint" => "Finger Paint", "fira_code" => "Fira Code", "fira_mono" => "Fira Mono", "fira_sans" => "Fira Sans", "fira_sans_condensed" => "Fira Sans Condensed", 
    "fira_sans_extra_condensed" => "Fira Sans Extra Condensed", "fjalla_one" => "Fjalla One", "fjord_one" => "Fjord One", "flamenco" => "Flamenco", "flavors" => "Flavors", "fondamento" => "Fondamento", "fontdiner_swanky" => "Fontdiner Swanky", "forum" => "Forum", "francois_one" => "Francois One", "frank_ruhl_libre" => "Frank Ruhl Libre", "freckle_face" => "Freckle Face", "fredericka_the_great" => "Fredericka the Great", "fredoka_one" => "Fredoka One", "freehand" => "Freehand", "fresca" => "Fresca", "frijole" => "Frijole", "fruktur" => "Fruktur", "fugaz_one" => "Fugaz One", "gfs_didot" => "GFS Didot", "gfs_neohellenic" => "GFS Neohellenic", "gabriela" => "Gabriela", "gaegu" => "Gaegu", "gafata" => "Gafata", "galada" => "Galada", "galdeano" => "Galdeano", "galindo" => "Galindo", "gamja_flower" => "Gamja Flower", "gayathri" => "Gayathri", "gelasio" => "Gelasio", "gentium_basic" => "Gentium Basic", "gentium_book_basic" => "Gentium Book Basic", "geo" => "Geo", "geostar" => "Geostar", "geostar_fill" => "Geostar Fill", "germania_one" => "Germania One", "gidugu" => "Gidugu", "gilda_display" => "Gilda Display", "girassol" => "Girassol", "give_you_glory" => "Give You Glory", "glass_antiqua" => "Glass Antiqua", "glegoo" => "Glegoo", "gloria_hallelujah" => "Gloria Hallelujah", "goblin_one" => "Goblin One", "gochi_hand" => "Gochi Hand", "goldman" => "Goldman", "gorditas" => "Gorditas", "gothic_a1" => "Gothic A1", "gotu" => "Gotu", "goudy_bookletter_1911" => "Goudy Bookletter 1911", "graduate" => "Graduate", "grand_hotel" => "Grand Hotel", "grandstander" => "Grandstander", "gravitas_one" => "Gravitas One", "great_vibes" => "Great Vibes", "grenze" => "Grenze", "grenze_gotisch" => "Grenze Gotisch", "griffy" => "Griffy", "gruppo" => "Gruppo", "gudea" => "Gudea", "gugi" => "Gugi", "gupter" => "Gupter", "gurajada" => "Gurajada", "habibi" => "Habibi", "halant" => "Halant", "hammersmith_one" => "Hammersmith One", "hanalei" => "Hanalei", "hanalei_fill" => "Hanalei Fill", "handlee" => "Handlee", "hanuman" => "Hanuman", "happy_monkey" => "Happy Monkey", "harmattan" => "Harmattan", "headland_one" => "Headland One", "heebo" => "Heebo", "henny_penny" => "Henny Penny", "hepta_slab" => "Hepta Slab", "herr_von_muellerhoff" => "Herr Von Muellerhoff", "hi_melody" => "Hi Melody", "hind" => "Hind", "hind_guntur" => "Hind Guntur", "hind_madurai" => "Hind Madurai", "hind_siliguri" => "Hind Siliguri", "hind_vadodara" => "Hind Vadodara", "holtwood_one_sc" => "Holtwood One SC", "homemade_apple" => "Homemade Apple", "homenaje" => "Homenaje", "ibm_plex_mono" => "IBM Plex Mono", "ibm_plex_sans" => "IBM Plex Sans", "ibm_plex_sans_condensed" => "IBM Plex Sans Condensed", "ibm_plex_serif" => "IBM Plex Serif", "im_fell_dw_pica" => "IM Fell DW Pica", "im_fell_dw_pica_sc" => "IM Fell DW Pica SC", "im_fell_double_pica" => "IM Fell Double Pica", "im_fell_double_pica_sc" => "IM Fell Double Pica SC", "im_fell_english" => "IM Fell English", "im_fell_english_sc" => "IM Fell English SC", "im_fell_french_canon" => "IM Fell French Canon", "im_fell_french_canon_sc" => "IM Fell French Canon SC", "im_fell_great_primer" => "IM Fell Great Primer", "im_fell_great_primer_sc" => "IM Fell Great Primer SC", "ibarra_real_nova" => "Ibarra Real Nova", "iceberg" => "Iceberg", "iceland" => "Iceland", "imprima" => "Imprima", "inconsolata" => "Inconsolata", "inder" => "Inder", "indie_flower" => "Indie Flower", "inika" => "Inika", "inknut_antiqua" => "Inknut Antiqua", "inria_sans" => "Inria Sans", "inria_serif" => "Inria Serif", "inter" => "Inter", "irish_grover" => "Irish Grover", "istok_web" => "Istok Web", "italiana" => "Italiana", "italianno" => "Italianno", "itim" => "Itim", "jacques_francois" => "Jacques Francois", "jacques_francois_shadow" => "Jacques Francois Shadow", "jaldi" => "Jaldi", "jetbrains_mono" => "JetBrains Mono", "jim_nightshade" => "Jim Nightshade", "jockey_one" => "Jockey One", "jolly_lodger" => "Jolly Lodger", "jomhuria" => "Jomhuria", "jomolhari" => "Jomolhari", "josefin_sans" => "Josefin Sans", "josefin_slab" => "Josefin Slab", "jost" => "Jost", "joti_one" => "Joti One", "jua" => "Jua", "judson" => "Judson", "julee" => "Julee", "julius_sans_one" => "Julius Sans One", "junge" => "Junge", "jura" => "Jura", "just_another_hand" => "Just Another Hand", "just_me_again_down_here" => "Just Me Again Down Here", "k2d" => "K2D", "kadwa" => "Kadwa", "kalam" => "Kalam", "kameron" => "Kameron", "kanit" => "Kanit", "kantumruy" => "Kantumruy", "karla" => "Karla", "karma" => "Karma", "katibeh" => "Katibeh", "kaushan_script" => "Kaushan Script", "kavivanar" => "Kavivanar", "kavoon" => "Kavoon", "kdam_thmor" => "Kdam Thmor", "keania_one" => "Keania One", "kelly_slab" => "Kelly Slab", "kenia" => "Kenia", "khand" => "Khand", "khmer" => "Khmer", "khula" => "Khula", "kirang_haerang" => "Kirang Haerang", "kite_one" => "Kite One", "knewave" => "Knewave", "koho" => "KoHo", "kodchasan" => "Kodchasan", "kosugi" => "Kosugi", "kosugi_maru" => "Kosugi Maru", "kotta_one" => "Kotta One", "koulen" => "Koulen", "kranky" => "Kranky", "kreon" => "Kreon", "kristi" => "Kristi", "krona_one" => "Krona One", "krub" => "Krub", "kufam" => "Kufam", "kulim_park" => "Kulim Park", "kumar_one" => "Kumar One", "kumar_one_outline" => "Kumar One Outline", "kumbh_sans" => "Kumbh Sans", "kurale" => "Kurale", "la_belle_aurore" => "La Belle Aurore", "lacquer" => "Lacquer", "laila" => "Laila", "lakki_reddy" => "Lakki Reddy", "lalezar" => "Lalezar", "lancelot" => "Lancelot", "langar" => "Langar", "lateef" => "Lateef", "lato" => "Lato", "league_script" => "League Script", "leckerli_one" => "Leckerli One", "ledger" => "Ledger", "lekton" => "Lekton", "lemon" => "Lemon", "lemonada" => "Lemonada", "lexend_deca" => "Lexend Deca", "lexend_exa" => "Lexend Exa", "lexend_giga" => "Lexend Giga", "lexend_mega" => "Lexend Mega", "lexend_peta" => "Lexend Peta", "lexend_tera" => "Lexend Tera", "lexend_zetta" => "Lexend Zetta", "libre_barcode_128" => "Libre Barcode 128", "libre_barcode_128_text" => "Libre Barcode 128 Text", "libre_barcode_39" => "Libre Barcode 39", "libre_barcode_39_extended" => "Libre Barcode 39 Extended", "libre_barcode_39_extended_text" => "Libre Barcode 39 Extended Text", "libre_barcode_39_text" => "Libre Barcode 39 Text", "libre_barcode_ean13_text" => "Libre Barcode EAN13 Text", "libre_baskerville" => "Libre Baskerville", "libre_caslon_display" => "Libre Caslon Display", "libre_caslon_text" => "Libre Caslon Text", "libre_franklin" => "Libre Franklin", "life_savers" => "Life Savers", "lilita_one" => "Lilita One", "lily_script_one" => "Lily Script One", "limelight" => "Limelight", "linden_hill" => "Linden Hill", "literata" => "Literata", "liu_jian_mao_cao" => "Liu Jian Mao Cao", "livvic" => "Livvic", "lobster" => "Lobster", "lobster_two" => "Lobster Two", "londrina_outline" => "Londrina Outline", "londrina_shadow" => "Londrina Shadow", "londrina_sketch" => "Londrina Sketch", "londrina_solid" => "Londrina Solid", "long_cang" => "Long Cang", "lora" => "Lora", "love_ya_like_a_sister" => "Love Ya Like A Sister", "loved_by_the_king" => "Loved by the King", "lovers_quarrel" => "Lovers Quarrel", "luckiest_guy" => "Luckiest Guy", "lusitana" => "Lusitana", "lustria" => "Lustria", "m_plus_1p" => "M PLUS 1p", "m_plus_rounded_1c" => "M PLUS Rounded 1c", "ma_shan_zheng" => "Ma Shan Zheng", "macondo" => "Macondo", "macondo_swash_caps" => "Macondo Swash Caps", "mada" => "Mada", "magra" => "Magra", "maiden_orange" => "Maiden Orange", "maitree" => "Maitree", "major_mono_display" => "Major Mono Display", "mako" => "Mako", "mali" => "Mali", "mallanna" => "Mallanna", "mandali" => "Mandali", "manjari" => "Manjari", "manrope" => "Manrope", "mansalva" => "Mansalva", "manuale" => "Manuale", "marcellus" => "Marcellus", "marcellus_sc" => "Marcellus SC", "marck_script" => "Marck Script", "margarine" => "Margarine", "markazi_text" => "Markazi Text", "marko_one" => "Marko One", "marmelad" => "Marmelad", "martel" => "Martel", "martel_sans" => "Martel Sans", "marvel" => "Marvel", "mate" => "Mate", "mate_sc" => "Mate SC", "maven_pro" => "Maven Pro", "mclaren" => "McLaren", "meddon" => "Meddon", "medievalsharp" => "MedievalSharp", "medula_one" => "Medula One", "meera_inimai" => "Meera Inimai", "megrim" => "Megrim", "meie_script" => "Meie Script", "merienda" => "Merienda", "merienda_one" => "Merienda One", "merriweather" => "Merriweather", "merriweather_sans" => "Merriweather Sans", "metal" => "Metal", "metal_mania" => "Metal Mania", "metamorphous" => "Metamorphous", "metrophobic" => "Metrophobic", "michroma" => "Michroma", "milonga" => "Milonga", "miltonian" => "Miltonian", "miltonian_tattoo" => "Miltonian Tattoo", "mina" => "Mina", "miniver" => "Miniver", "miriam_libre" => "Miriam Libre", "mirza" => "Mirza", "miss_fajardose" => "Miss Fajardose", "mitr" => "Mitr", "modak" => "Modak", "modern_antiqua" => "Modern Antiqua", "mogra" => "Mogra", "molengo" => "Molengo", "molle" => "Molle", "monda" => "Monda", "monofett" => "Monofett", "monoton" => "Monoton", "monsieur_la_doulaise" => "Monsieur La Doulaise", "montaga" => "Montaga", "montez" => "Montez", "montserrat" => "Montserrat", "montserrat_alternates" => "Montserrat Alternates", "montserrat_subrayada" => "Montserrat Subrayada", "moul" => "Moul", "moulpali" => "Moulpali", "mountains_of_christmas" => "Mountains of Christmas", "mouse_memoirs" => "Mouse Memoirs", "mr_bedfort" => "Mr Bedfort", "mr_dafoe" => "Mr Dafoe", "mr_de_haviland" => "Mr De Haviland", "mrs_saint_delafield" => "Mrs Saint Delafield", "mrs_sheppards" => "Mrs Sheppards", "mukta" => "Mukta", "mukta_mahee" => "Mukta Mahee", "mukta_malar" => "Mukta Malar", "mukta_vaani" => "Mukta Vaani", "mulish" => "Mulish", "museomoderno" => "MuseoModerno", "mystery_quest" => "Mystery Quest", "ntr" => "NTR", "nanum_brush_script" => "Nanum Brush Script", "nanum_gothic" => "Nanum Gothic", "nanum_gothic_coding" => "Nanum Gothic Coding", "nanum_myeongjo" => "Nanum Myeongjo", 
    "nanum_pen_script" => "Nanum Pen Script", "nerko_one" => "Nerko One", "neucha" => "Neucha", "neuton" => "Neuton", "new_rocker" => "New Rocker", "news_cycle" => "News Cycle", "niconne" => "Niconne", "niramit" => "Niramit", "nixie_one" => "Nixie One", "nobile" => "Nobile", "nokora" => "Nokora", "norican" => "Norican", "nosifer" => "Nosifer", "notable" => "Notable", "nothing_you_could_do" => "Nothing You Could Do", "noticia_text" => "Noticia Text", "noto_sans" => "Noto Sans", "noto_sans_hk" => "Noto Sans HK", "noto_sans_jp" => "Noto Sans JP", "noto_sans_kr" => "Noto Sans KR", "noto_sans_sc" => "Noto Sans SC", "noto_sans_tc" => "Noto Sans TC", "noto_serif" => "Noto Serif", "noto_serif_jp" => "Noto Serif JP", "noto_serif_kr" => "Noto Serif KR", "noto_serif_sc" => "Noto Serif SC", "noto_serif_tc" => "Noto Serif TC", "nova_cut" => "Nova Cut", "nova_flat" => "Nova Flat", "nova_mono" => "Nova Mono", "nova_oval" => "Nova Oval", "nova_round" => "Nova Round", "nova_script" => "Nova Script", "nova_slim" => "Nova Slim", "nova_square" => "Nova Square", "numans" => "Numans", "nunito" => "Nunito", "nunito_sans" => "Nunito Sans", "odibee_sans" => "Odibee Sans", "odor_mean_chey" => "Odor Mean Chey", "offside" => "Offside", "old_standard_tt" => "Old Standard TT", "oldenburg" => "Oldenburg", "oleo_script" => "Oleo Script", "oleo_script_swash_caps" => "Oleo Script Swash Caps", "open_sans" => "Open Sans", "open_sans_condensed" => "Open Sans Condensed", "oranienbaum" => "Oranienbaum", "orbitron" => "Orbitron", "oregano" => "Oregano", "orienta" => "Orienta", "original_surfer" => "Original Surfer", "oswald" => "Oswald", "over_the_rainbow" => "Over the Rainbow", "overlock" => "Overlock", "overlock_sc" => "Overlock SC", "overpass" => "Overpass", "overpass_mono" => "Overpass Mono", "ovo" => "Ovo", "oxanium" => "Oxanium", "oxygen" => "Oxygen", "oxygen_mono" => "Oxygen Mono", "pt_mono" => "PT Mono", "pt_sans" => "PT Sans", "pt_sans_caption" => "PT Sans Caption", "pt_sans_narrow" => "PT Sans Narrow", "pt_serif" => "PT Serif", "pt_serif_caption" => "PT Serif Caption", "pacifico" => "Pacifico", "padauk" => "Padauk", "palanquin" => "Palanquin", "palanquin_dark" => "Palanquin Dark", "pangolin" => "Pangolin", "paprika" => "Paprika", "parisienne" => "Parisienne", "passero_one" => "Passero One", "passion_one" => "Passion One", "pathway_gothic_one" => "Pathway Gothic One", "patrick_hand" => "Patrick Hand", "patrick_hand_sc" => "Patrick Hand SC", "pattaya" => "Pattaya", "patua_one" => "Patua One", "pavanam" => "Pavanam", "paytone_one" => "Paytone One", "peddana" => "Peddana", "peralta" => "Peralta", "permanent_marker" => "Permanent Marker", "petit_formal_script" => "Petit Formal Script", "petrona" => "Petrona", "philosopher" => "Philosopher", "piazzolla" => "Piazzolla", "piedra" => "Piedra", "pinyon_script" => "Pinyon Script", "pirata_one" => "Pirata One", "plaster" => "Plaster", "play" => "Play", "playball" => "Playball", "playfair_display" => "Playfair Display", "playfair_display_sc" => "Playfair Display SC", "podkova" => "Podkova", "poiret_one" => "Poiret One", "poller_one" => "Poller One", "poly" => "Poly", "pompiere" => "Pompiere", "pontano_sans" => "Pontano Sans", "poor_story" => "Poor Story", "poppins" => "Poppins", "port_lligat_sans" => "Port Lligat Sans", "port_lligat_slab" => "Port Lligat Slab", "pragati_narrow" => "Pragati Narrow", "prata" => "Prata", "preahvihear" => "Preahvihear", "press_start_2p" => "Press Start 2P", "pridi" => "Pridi", "princess_sofia" => "Princess Sofia", "prociono" => "Prociono", "prompt" => "Prompt", "prosto_one" => "Prosto One", "proza_libre" => "Proza Libre", "public_sans" => "Public Sans", "puritan" => "Puritan", "purple_purse" => "Purple Purse", "quando" => "Quando", "quantico" => "Quantico", "quattrocento" => "Quattrocento", "quattrocento_sans" => "Quattrocento Sans", "questrial" => "Questrial", "quicksand" => "Quicksand", "quintessential" => "Quintessential", "qwigley" => "Qwigley", "racing_sans_one" => "Racing Sans One", "radley" => "Radley", "rajdhani" => "Rajdhani", "rakkas" => "Rakkas", "raleway" => "Raleway", "raleway_dots" => "Raleway Dots", "ramabhadra" => "Ramabhadra", "ramaraja" => "Ramaraja", "rambla" => "Rambla", "rammetto_one" => "Rammetto One", "ranchers" => "Ranchers", "rancho" => "Rancho", "ranga" => "Ranga", "rasa" => "Rasa", "rationale" => "Rationale", "ravi_prakash" => "Ravi Prakash", "recursive" => "Recursive", "red_hat_display" => "Red Hat Display", "red_hat_text" => "Red Hat Text", "red_rose" => "Red Rose", "redressed" => "Redressed", "reem_kufi" => "Reem Kufi", "reenie_beanie" => "Reenie Beanie", "revalia" => "Revalia", "rhodium_libre" => "Rhodium Libre", "ribeye" => "Ribeye", "ribeye_marrow" => "Ribeye Marrow", "righteous" => "Righteous", "risque" => "Risque", "roboto" => "Roboto", "roboto_condensed" => "Roboto Condensed", "roboto_mono" => "Roboto Mono", "roboto_slab" => "Roboto Slab", "rochester" => "Rochester", "rock_salt" => "Rock Salt", "rokkitt" => "Rokkitt", "romanesco" => "Romanesco", "ropa_sans" => "Ropa Sans", "rosario" => "Rosario", "rosarivo" => "Rosarivo", "rouge_script" => "Rouge Script", "rowdies" => "Rowdies", "rozha_one" => "Rozha One", "rubik" => "Rubik", "rubik_mono_one" => "Rubik Mono One", "ruda" => "Ruda", "rufina" => "Rufina", "ruge_boogie" => "Ruge Boogie", "ruluko" => "Ruluko", "rum_raisin" => "Rum Raisin", "ruslan_display" => "Ruslan Display", "russo_one" => "Russo One", "ruthie" => "Ruthie", "rye" => "Rye", "sacramento" => "Sacramento", "sahitya" => "Sahitya", "sail" => "Sail", "saira" => "Saira", "saira_condensed" => "Saira Condensed", "saira_extra_condensed" => "Saira Extra Condensed", "saira_semi_condensed" => "Saira Semi Condensed", "saira_stencil_one" => "Saira Stencil One", "salsa" => "Salsa", "sanchez" => "Sanchez", "sancreek" => "Sancreek", "sansita" => "Sansita", "sansita_swashed" => "Sansita Swashed", "sarabun" => "Sarabun", "sarala" => "Sarala", "sarina" => "Sarina", "sarpanch" => "Sarpanch", "satisfy" => "Satisfy", "sawarabi_gothic" => "Sawarabi Gothic", "sawarabi_mincho" => "Sawarabi Mincho", "scada" => "Scada", "scheherazade" => "Scheherazade", "schoolbell" => "Schoolbell", "scope_one" => "Scope One", "seaweed_script" => "Seaweed Script", "secular_one" => "Secular One", "sedgwick_ave" => "Sedgwick Ave", "sedgwick_ave_display" => "Sedgwick Ave Display", "sen" => "Sen", "sevillana" => "Sevillana", "seymour_one" => "Seymour One", "shadows_into_light" => "Shadows Into Light", "shadows_into_light_two" => "Shadows Into Light Two", "shanti" => "Shanti", "share" => "Share", "share_tech" => "Share Tech", "share_tech_mono" => "Share Tech Mono", "shojumaru" => "Shojumaru", "short_stack" => "Short Stack", "shrikhand" => "Shrikhand", "siemreap" => "Siemreap", "sigmar_one" => "Sigmar One", "signika" => "Signika", "signika_negative" => "Signika Negative", "simonetta" => "Simonetta", "single_day" => "Single Day", "sintony" => "Sintony", "sirin_stencil" => "Sirin Stencil", "six_caps" => "Six Caps", "skranji" => "Skranji", "slabo_13px" => "Slabo 13px", "slabo_27px" => "Slabo 27px", "slackey" => "Slackey", "smokum" => "Smokum", "smythe" => "Smythe", "sniglet" => "Sniglet", "snippet" => "Snippet", "snowburst_one" => "Snowburst One", "sofadi_one" => "Sofadi One", "sofia" => "Sofia", "solway" => "Solway", "song_myung" => "Song Myung", "sonsie_one" => "Sonsie One", "sora" => "Sora", "sorts_mill_goudy" => "Sorts Mill Goudy", "source_code_pro" => "Source Code Pro", "source_sans_pro" => "Source Sans Pro", "source_serif_pro" => "Source Serif Pro", "space_grotesk" => "Space Grotesk", "space_mono" => "Space Mono", "spartan" => "Spartan", "special_elite" => "Special Elite", "spectral" => "Spectral", "spectral_sc" => "Spectral SC", "spicy_rice" => "Spicy Rice", "spinnaker" => "Spinnaker", "spirax" => "Spirax", "squada_one" => "Squada One", "sree_krushnadevaraya" => "Sree Krushnadevaraya", "sriracha" => "Sriracha", "srisakdi" => "Srisakdi", "staatliches" => "Staatliches", "stalemate" => "Stalemate", "stalinist_one" => "Stalinist One", "stardos_stencil" => "Stardos Stencil", "stint_ultra_condensed" => "Stint Ultra Condensed", "stint_ultra_expanded" => "Stint Ultra Expanded", "stoke" => "Stoke", "strait" => "Strait", "stylish" => "Stylish", "sue_ellen_francisco" => "Sue Ellen Francisco", "suez_one" => "Suez One", "sulphur_point" => "Sulphur Point", "sumana" => "Sumana", "sunflower" => "Sunflower", "sunshiney" => "Sunshiney", "supermercado_one" => "Supermercado One", "sura" => "Sura", "suranna" => "Suranna", "suravaram" => "Suravaram", "suwannaphum" => "Suwannaphum", "swanky_and_moo_moo" => "Swanky and Moo Moo", "syncopate" => "Syncopate", "syne" => "Syne", "syne_mono" => "Syne Mono", "syne_tactile" => "Syne Tactile", "tajawal" => "Tajawal", "tangerine" => "Tangerine", "taprom" => "Taprom", "tauri" => "Tauri", "taviraj" => "Taviraj", "teko" => "Teko", "telex" => "Telex", "tenali_ramakrishna" => "Tenali Ramakrishna", "tenor_sans" => "Tenor Sans", "text_me_one" => "Text Me One", "texturina" => "Texturina", "thasadith" => "Thasadith", "the_girl_next_door" => "The Girl Next Door", "tienne" => "Tienne", "tillana" => "Tillana", "timmana" => "Timmana", "tinos" => "Tinos", "titan_one" => "Titan One", "titillium_web" => "Titillium Web", "tomorrow" => "Tomorrow", "trade_winds" => "Trade Winds", "trirong" => "Trirong", "trispace" => "Trispace", "trocchi" => "Trocchi", "trochut" => "Trochut", "trykker" => "Trykker", "tulpen_one" => "Tulpen One", "turret_road" => "Turret Road", "ubuntu" => "Ubuntu", "ubuntu_condensed" => "Ubuntu Condensed", "ubuntu_mono" => "Ubuntu Mono", "ultra" => "Ultra", "uncial_antiqua" => "Uncial Antiqua", "underdog" => "Underdog", "unica_one" => "Unica One", "unifrakturcook" => "UnifrakturCook", "unifrakturmaguntia" => "UnifrakturMaguntia", "unkempt" => "Unkempt", "unlock" => "Unlock", "unna" => "Unna", "vt323" => "VT323", "vampiro_one" => "Vampiro One", "varela" => "Varela", 
    "varela_round" => "Varela Round", "varta" => "Varta", "vast_shadow" => "Vast Shadow", "vesper_libre" => "Vesper Libre", "viaoda_libre" => "Viaoda Libre", "vibes" => "Vibes", "vibur" => "Vibur", "vidaloka" => "Vidaloka", "viga" => "Viga", "voces" => "Voces", "volkhov" => "Volkhov", "vollkorn" => "Vollkorn", "vollkorn_sc" => "Vollkorn SC", "voltaire" => "Voltaire", "waiting_for_the_sunrise" => "Waiting for the Sunrise", "wallpoet" => "Wallpoet", "walter_turncoat" => "Walter Turncoat", "warnes" => "Warnes", "wellfleet" => "Wellfleet", "wendy_one" => "Wendy One", "wire_one" => "Wire One", "work_sans" => "Work Sans", "xanh_mono" => "Xanh Mono", "yanone_kaffeesatz" => "Yanone Kaffeesatz", "yantramanav" => "Yantramanav", "yatra_one" => "Yatra One", "yellowtail" => "Yellowtail", "yeon_sung" => "Yeon Sung", "yeseva_one" => "Yeseva One", "yesteryear" => "Yesteryear", "yrsa" => "Yrsa", "zcool_kuaile" => "ZCOOL KuaiLe", "zcool_qingke_huangyou" => "ZCOOL QingKe HuangYou", "zcool_xiaowei" => "ZCOOL XiaoWei", "zeyada" => "Zeyada", "zhi_mang_xing" => "Zhi Mang Xing", "zilla_slab" => "Zilla Slab", "zilla_slab_highlight" => "Zilla Slab Highlight" );
    } else {
		foreach($fonts as $font) {
      $metin = strtolower($font['family']);
      $bul   = " ";
      $degistir   = "_";
      $metin = str_replace($bul, $degistir, $metin);
			$list[$metin] .= $font['family'];
		}
  }
  
  return $list;
}