<?php

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


if( ! class_exists( 'KANEWS_MEMBERSHIP' ) ) {

	class KANEWS_MEMBERSHIP {

    private $user_id_being_edited;
    
    function __construct() {

      add_action( 'admin_init', array( $this, 'admin_init' ) );
      add_action( 'init', array( $this, 'possibly_redirect' ) );

      // Avatar
      add_action( 'admin_init',                array( $this, 'admin_init'               )        );
      add_action( 'show_user_profile',         array( $this, 'edit_user_profile'        )        );
      add_action( 'edit_user_profile',         array( $this, 'edit_user_profile'        )        );
      add_action( 'personal_options_update',   array( $this, 'edit_user_profile_update' )        );
      add_action( 'edit_user_profile_update',  array( $this, 'edit_user_profile_update' )        );
      add_action( 'bbp_user_edit_after_about', array( $this, 'bbpress_user_profile'     )        );
  
      // Filters
      add_filter( 'get_avatar', array( $this, 'get_avatar' ), 10, 5 );
      add_filter( 'avatar_defaults', array( $this, 'avatar_defaults' ) );
      add_filter( 'manage_users_columns', array( $this, 'admin_user_column' ), 1 );
      add_filter( 'manage_users_custom_column', array( $this, 'admin_user_column_content'), 10, 3);

      // Account
      add_filter( 'wp_ajax_nopriv_kanews_ajax_login', array( $this, 'kanews_ajax_login' ) );
      add_filter( 'wp_ajax_nopriv_kanews_ajax_register', array( $this, 'kanews_ajax_register' ) );
      add_filter( 'wp_ajax_kanews_ajax_profile', array( $this, 'kanews_ajax_profile' ) );
      add_filter( 'wp_ajax_kanews_ajax_subscribe_category', array( $this, 'kanews_ajax_subscribe_category' ) );
      add_filter( 'wp_ajax_kanews_ajax_submit_post', array( $this, 'kanews_ajax_submit_post' ) );

      // Archives
			add_filter( 'template_redirect', array( $this, 'disable_author_page' ) );
			
			// Extra Fields
			add_action( 'show_user_profile', array( $this, 'add_user_profile_fields'  ) );
			add_action( 'edit_user_profile', array( $this, 'add_user_profile_fields'  ) );
			add_action( 'personal_options_update', array( $this, 'save_user_profile_fields'  ) );
			add_action( 'edit_user_profile_update', array( $this, 'save_user_profile_fields'  ) );

		}
		
		/**
		* User ID Column
		*
		* @since 1.0.0
		* */
		function admin_user_column($columns ) {
			$columns['user_id'] = 'ID';
			$columns['user_badge'] = 'Rozetler';
			return $columns;
		}		
		
		/**
		* User ID Column Content
		*
		* @since 1.0.0
		* */
		function admin_user_column_content($value, $column_name, $user_id) {
			if ( 'user_id' == $column_name )
			return $user_id;

			if ( 'user_badge' == $column_name ) {
				$user = new WP_User( $user_id );
				$role = $user->roles;
				$badges = kanews_get_option('user-badge');
				$out = '';
				if (!empty($badges)){
					foreach($badges as $badge) {
						if ( isset($badge['title']) && !empty($badge['title']) && !empty($badge['role']) && isset($badge['role'])) {
							if($role[0] == $badge['role']){
								$out .= '<button class="button" style="margin: 0 2px;border-color:'.$badge['color'].';background-color: '.$badge['color'].';color:#fff">'.$badge['title'].'</button>';
							}
						}
					}
					return $out;
				}
			}

			return $value;
		}
		
		
		/**
    * Ajax Submit Post
    *
    * @since 1.0.0 
    **/
    function kanews_ajax_submit_post() {
			// Security
			check_ajax_referer( 'submit_action', 'submit_field' );
			
			$uid = get_current_user_id();

			$title = trim( sanitize_text_field( $_POST[ 'post_title' ] ) );
			$post_excerpt = trim( sanitize_text_field( $_POST[ 'post_excerpt' ] ) );
			$content = $_POST[ 'kanews-add-posts' ];

			if ( !is_user_logged_in() ) {
        wp_send_json_error( array( 'message' => esc_html__( 'Giriş yapmalısınız!', 'kanews' ) ) );
        exit();
			}

			if ( empty($title) ) {
        wp_send_json_error( array( 'message' => esc_html__( 'İçeriği bir başlığı olması gerekir!', 'kanews' ) ) );
        exit();
			}

			if ( empty($content) ) {
        wp_send_json_error( array( 'message' => esc_html__( 'Boş içerik gönderemezsiniz!', 'kanews' ) ) );
        exit();
			}

			
			$post_info = array(
				'post_title' => wp_strip_all_tags( $title ),
				'post_content' => wpautop($content),
				'post_status' => 'publish',
				'post_author' => $uid,
				'post_type' => 'post',
			);
			$pid = wp_insert_post( $post_info );

			update_post_meta( $pid, 'kanews_post_excerpt', $post_excerpt); 

			update_post_meta($pid,'_thumbnail_id',$attach_id);
			set_post_thumbnail( $pid, $attach_id );	

			if ( is_wp_error( $pid ) ) {
        wp_send_json_error( array( 'message' => $pid->get_error_message() ) );
        exit();
      }

      wp_send_json_success( array( 'message' => esc_html__( 'İçeriğiniz başarıyla gönderilmiştir.', 'kanews' ) ) );
      exit();
    }

    /**
    * Ajax Register
    *
    * @since 1.0.0 
    **/
    function kanews_ajax_subscribe_category() {
			// Security
			$nonce = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : 0;
			if ( !wp_verify_nonce( $nonce, 'kanews-cat-nonce' ) ) {
				exit( __( 'İzin verilmedi!', 'kanews' ) );
			}
			
			$uid = get_current_user_id();

			if ( is_wp_error( $register_status ) ) {
        wp_send_json_error( array( 'message' => $register_status->get_error_message() ) );
        exit();
			}

			if ( !is_user_logged_in() ) {
        wp_send_json_error( array( 'message' => esc_html__( 'Giriş yapmalısınız!', 'kanews' ) ) );
        exit();
			}
			
			$cats = get_user_option( 'kanews_subscribe_category', $uid );
			$new_cat = trim( sanitize_text_field( $_POST[ 'cat_id' ] ) );
			
			foreach ($cats as $key => $value) {
				if($value == $new_cat) {
					unset($cats[$key]);
					update_user_option($uid, 'kanews_subscribe_category', $cats);
					wp_send_json_success();
     			exit();
				}
			}

			$cats[] = $new_cat;
			update_user_option($uid, 'kanews_subscribe_category', $cats);

      wp_send_json_success();
      exit();
    }
		

    /**
    * Ajax Register
    *
    * @since 1.0.0 
    **/
    function kanews_ajax_register() {
      check_ajax_referer( 'register_action', 'register_field' );

      $username = trim( sanitize_text_field( $_POST[ 'username' ] ) );
      $email = trim( sanitize_email( $_POST[ 'email' ] ) );
      $password = trim( sanitize_text_field( $_POST[ 'password' ] ) );
      $password2 = trim( sanitize_text_field( $_POST[ 'password2' ] ) );


      if ( ! is_email( $email ) ) {
        wp_send_json_error( array( 'message' => esc_html__( 'Lütfen doğru bir e-posta adresi girin!', 'kanews' ) ) );
        exit();
      }

      if ( $password != $password2 ) {
        wp_send_json_error( array( 'message' => esc_html__( 'Girdiğiniz şifreler eşleşmiyor!', 'kanews' ) ) );
        exit();
      }

      $uppercase = preg_match('@[A-Z]@', $password);
      $number    = preg_match('@[0-9]@', $password);
      $specialChars = preg_match('@[^\w]@', $password);

      if(!$uppercase ||!$number || !$specialChars || strlen($password) < 8) {
        wp_send_json_error( array( 'message' => esc_html__( 'Şifreniz en az 8 karakter uzunluğunda olmalı ve en az bir büyük harf, bir rakam ve bir özel karakter içermelidir.', 'kanews' ) ) );
        exit();
      }

      $register_fields = array(
        'user_login' => $username,
        'user_email' => $email,
        'user_pass'  => $password,
        'show_admin_bar_front' => 'false',
        'role' => 'subscriber'
      );

      $register_status = wp_insert_user( $register_fields );

      if ( is_wp_error( $register_status ) ) {
        wp_send_json_error( array( 'message' => $register_status->get_error_message() ) );
        exit();
      }

      $user = get_user_by( 'ID', $register_status );
      wp_set_auth_cookie( $user->ID );
      wp_set_current_user( $user->ID );
      do_action( 'wp_login', $user->user_login, $user );

      wp_send_json_success( array( 'message' => esc_html__( 'Kaydınız tamamlanmıştır, yönlendiriliyorsunuz..', 'kanews' ) ) );
      exit();
    }

    /**
    * Ajax profile update
    *
    * @since 1.0.0 
    **/
    function kanews_ajax_profile(){
      check_ajax_referer( 'profile_action', 'profile_field' );

      $user_id = get_current_user_id();

      $nickname = trim( sanitize_text_field( $_POST[ 'nickname' ] ) );
      $first_name = trim( sanitize_text_field( $_POST[ 'first-name' ] ) );
      $last_name = trim( sanitize_text_field( $_POST[ 'last-name' ] ) );
      $display_name = trim( sanitize_text_field( $_POST[ 'display_name' ] ) );
      $email = trim( sanitize_text_field( $_POST[ 'email' ] ) );
      $pass1 = trim( sanitize_text_field( $_POST[ 'pass1' ] ) );
      $pass2 = trim( sanitize_text_field( $_POST[ 'pass2' ] ) );
      $facebook = trim( sanitize_text_field( $_POST[ 'facebook' ] ) );
      $facebook = trim( sanitize_text_field( $_POST[ 'twitter' ] ) );
      $instagram = trim( sanitize_text_field( $_POST[ 'instagram' ] ) );
      $linkedin = trim( sanitize_text_field( $_POST[ 'linkedin' ] ) );
      $youtube = trim( sanitize_text_field( $_POST[ 'youtube' ] ) );

      if ( !empty( $email ) ){
        if (!is_email($email)) {
          wp_send_json_error( array( 'message' => esc_html__( 'Lütfen doğru bir e-posta adresi girin!', 'kanews' ) ) );
          exit();
        } elseif( email_exists($email ) && email_exists($email) != $user_id ) {
          wp_send_json_error( array( 'message' => esc_html__( 'Bu e-posta başka bir kullanıcı tarafından kullanılıyor. farklı bir e-posta adresi deneyin.', 'kanews' ) ) );
          exit();
        } else {
          wp_update_user( array( 'ID' => $user_id, 'user_email' => esc_attr( $_POST['email'] ) ) );
        }
      }

      if ( !empty( $pass1 ) && !empty( $pass2 ) ) {
        if ( $pass1 != $pass2 ) {
					wp_send_json_error( array( 'message' => esc_html__( 'Girdiğiniz şifreler eşleşmiyor!', 'kanews' ) ) );
          exit();
        } else {
          wp_update_user( array( 'ID' => $user_id, 'user_pass' => $pass1 ) );
        }
      }

      $user_fields = array(
        'ID'           => $user_id,
        'nickname'     => $nickname,
        'first_name'   => $first_name,
        'last_name'    => $last_name,
        'display_name' => $display_name
      );

			$user_result = wp_update_user( $user_fields );
			
			update_user_meta( $user_id,'facebook_profile', sanitize_text_field( $_POST['facebook_profile'] ) );
			update_user_meta( $user_id,'twitter_profile', sanitize_text_field( $_POST['twitter_profile'] ) );
			update_user_meta( $user_id,'instagram_profile', sanitize_text_field( $_POST['instagram_profile'] ) );
			update_user_meta( $user_id,'linkedin_profile', sanitize_text_field( $_POST['linkedin_profile'] ) );
			update_user_meta( $user_id,'youtube_profile', sanitize_text_field( $_POST['youtube_profile'] ) ); 

      if ( is_wp_error( $user_result ) ) {
        wp_send_json_error( array( 'message' => $user_result->get_error_message() ) );
        exit();
      }
      

      wp_send_json_success( array( 'message' => __( 'Profiliniz güncellenmiştir!', 'kanews' ) ) );
      exit();
    }

    /**
    * Ajax Login
    *
    * @since 1.0.0 
    **/
    function kanews_ajax_login(){

      check_ajax_referer( 'login_action', 'login_field' );
  
      $username = trim( sanitize_text_field( $_POST[ 'username' ] ) );
      $password = trim( sanitize_text_field( $_POST[ 'password' ] ) );
      $remember = trim( sanitize_text_field( $_POST[ 'rememberme' ] ) );
  
      $login_fields = array(
        'user_login'    => $username,
        'user_password' => $password,
        'remember'      => $remember
      );
  
      $login_status = wp_signon( $login_fields, is_ssl() );
  
      if ( is_wp_error( $login_status ) ) {
        wp_send_json_error( array( 'message' => $login_status->get_error_message() ) );
        exit();
      }
  
      wp_send_json_success( array( 'message' => esc_html__( 'Giriş başarılı, yönlendiriliyorsunuz..', 'ideabox' ) ) );
      exit();
    }

    /**
	  * Disable subscriber author archives
	  *
	  * @since 1.0.1
    **/
    function disable_author_page() {
      if(!is_author())
      return;

      global $wp_query;
      $user_info = get_userdata( $wp_query->query_vars['author'] );
      $user_roles = implode(', ', $user_info->roles);

      if ( $user_roles ==  "subscriber") {
          wp_redirect(get_option('home'), 301); 
          exit; 
      }
    }

		/**
		* Start the admin engine.
		*
		* @since 1.0.0
		**/
		public function admin_init() {

			// Register/add the Discussion setting to restrict avatar upload capabilites
			register_setting( 'discussion', 'basic_user_avatars_caps', array( $this, 'sanitize_options' ) );
			add_settings_field( 'basic-user-avatars-caps', __( 'Local Avatar Permissions', 'kanews' ), array( $this, 'avatar_settings_field' ), 'discussion', 'avatars' );
		}

		/**
		* Discussion settings option
		*
		* @since 1.0.0
		* @param array $args [description]
		**/
		public function avatar_settings_field( $args ) {
			$options = get_option( 'basic_user_avatars_caps' );
			?>
			<label for="basic_user_avatars_caps">
				<input type="checkbox" name="basic_user_avatars_caps" id="basic_user_avatars_caps" value="1" <?php checked( $options['basic_user_avatars_caps'], 1 ); ?>/>
				<?php _e( 'Only allow users with file upload capabilities to upload local avatars (Authors and above)', 'kanews' ); ?>
			</label>
			<?php
		}

		/**
		* Sanitize the Discussion settings option
		*
		* @since 1.0.0
		* @param array $input
		* @return array
		*/
		public function sanitize_options( $input ) {
			$new_input['basic_user_avatars_caps'] = empty( $input['basic_user_avatars_caps'] ) ? 0 : 1;
			return $new_input;
		}

		/**
		* Filter the avatar WordPress returns
		*
		* @since 1.0.0
		* @param string $avatar 
		* @param int/string/object $id_or_email
		* @param int $size 
		* @param string $default
		* @param boolean $alt 
		* @return string
		*/
		public function get_avatar( $avatar = '', $id_or_email, $size = 96, $default = '', $alt = false ) {

			// Determine if we recive an ID or string
			if ( is_numeric( $id_or_email ) )
				$user_id = (int) $id_or_email;
			elseif ( is_string( $id_or_email ) && ( $user = get_user_by( 'email', $id_or_email ) ) )
				$user_id = $user->ID;
			elseif ( is_object( $id_or_email ) && ! empty( $id_or_email->user_id ) )
				$user_id = (int) $id_or_email->user_id;

			if ( empty( $user_id ) )
				return $avatar;

			$local_avatars = get_user_meta( $user_id, 'basic_user_avatar', true );

			if ( empty( $local_avatars ) || empty( $local_avatars['full'] ) )
				return $avatar;

			$size = (int) $size;

			if ( empty( $alt ) )
				$alt = get_the_author_meta( 'display_name', $user_id );

			// Generate a new size
			if ( empty( $local_avatars[$size] ) ) {

				$upload_path      = wp_upload_dir();
				$avatar_full_path = str_replace( $upload_path['baseurl'], $upload_path['basedir'], $local_avatars['full'] );
				$image            = wp_get_image_editor( $avatar_full_path );
				$image_sized      = null;

				if ( ! is_wp_error( $image ) ) {
					$image->resize( $size, $size, true );
					$image_sized = $image->save();
				}

				// Deal with original being >= to original image (or lack of sizing ability).
				if ( empty( $image_sized ) || is_wp_error( $image_sized ) ) {
					$local_avatars[ $size ] = $local_avatars['full'];
				} else {
					$local_avatars[ $size ] = str_replace( $upload_path['basedir'], $upload_path['baseurl'], $image_sized['path'] );
				}

				// Save updated avatar sizes
				update_user_meta( $user_id, 'basic_user_avatar', $local_avatars );

			} elseif ( substr( $local_avatars[$size], 0, 4 ) != 'http' ) {
				$local_avatars[$size] = home_url( $local_avatars[$size] );
			}

			$author_class = is_author( $user_id ) ? ' current-author' : '' ;
			$avatar       = "<img alt='" . esc_attr( $alt ) . "' src='" . $local_avatars[$size] . "' class='avatar avatar-{$size}{$author_class} photo' height='{$size}' width='{$size}' />";

			return apply_filters( 'basic_user_avatar', $avatar );
		}

		/**
		* Form to display on the user profile edit screen
		*
		* @since 1.0.0
		* @param object $profileuser
		* @return
		*/
		public function edit_user_profile( $profileuser ) {

			// bbPress will try to auto-add this to user profiles - don't let it.
			// Instead we hook our own proper function that displays cleaner.
			if ( function_exists( 'is_bbpress') && is_bbpress() )
				return;
			?>
		
			<?php if(is_admin()): ?><h3><?php _e('Profil Fotoğrafı','kanews'); ?></h3><?php endif; ?>
			<table class="form-table form-avatar">
				<tr>

					<td style="margin-right:10px;display:inline-block;" valign="top">
						<?php echo get_avatar( $profileuser->ID, 50 ); ?>
					</td>
					<td>
					<?php
					$options = get_option( 'basic_user_avatars_caps' );
					if ( empty( $options['basic_user_avatars_caps'] ) || current_user_can( 'upload_files' ) ) {
						// Nonce security ftw
						wp_nonce_field( 'basic_user_avatar_nonce', '_basic_user_avatar_nonce', false );
						
						// File upload input
						echo '<input type="file" name="basic-user-avatar" id="basic-local-avatar" /><br />';

						if ( !empty( $profileuser->basic_user_avatar ) ) {
							echo '<input type="checkbox" name="basic-user-avatar-erase" value="1" /> ' . __( 'Avatarı Kaldır', 'kanews' ) . '<br />';
						}

					}
					?>
					</td>
				</tr>
			</table>
			<script type="text/javascript">var form = document.getElementById('your-profile');form.encoding = 'multipart/form-data';form.setAttribute('enctype', 'multipart/form-data');</script>
			<?php
		}

		/**
		* Update the user's avatar setting
		*
		* @since 1.0.0
		* @param int $user_id
		*/
		public function edit_user_profile_update( $user_id ) {

			// Check for nonce otherwise bail
			if ( ! isset( $_POST['_basic_user_avatar_nonce'] ) || ! wp_verify_nonce( $_POST['_basic_user_avatar_nonce'], 'basic_user_avatar_nonce' ) )
				return;

			if ( ! empty( $_FILES['basic-user-avatar']['name'] ) ) {
				
				$filename = $_FILES['basic-user-avatar']['name'];
				$ext = pathinfo($filename, PATHINFO_EXTENSION);
				$allowed = array('jpg', 'png', 'jpeg');
				if( in_array( $ext, $allowed ) ){
					

					// Allowed file extensions/types
					$mimes = array(
						'jpg|jpeg|jpe' => 'image/jpeg',
						'png'          => 'image/png',
					);

					// Front end support - shortcode, bbPress, etc
					if ( ! function_exists( 'wp_handle_upload' ) )
						require_once ABSPATH . 'wp-admin/includes/file.php';

				

					// Make user_id known to unique_filename_callback function
					$this->user_id_being_edited = $user_id; 
					$avatar = wp_handle_upload( $_FILES['basic-user-avatar'], array( 'mimes' => $mimes, 'test_form' => false, 'unique_filename_callback' => array( $this, 'unique_filename_callback' ) ) );

					// Handle failures
					if ( empty( $avatar['file'] ) ) {
						switch ( $avatar['error'] ) {
						case 'File type does not meet security guidelines. Try another.' :
							add_action( 'user_profile_update_errors', create_function( '$a', '$a->add("avatar_error",__("Please upload a valid image file for the avatar.","basic-user-avatars"));' ) );
							break;
						default :
							add_action( 'user_profile_update_errors', create_function( '$a', '$a->add("avatar_error","<strong>".__("There was an error uploading the avatar:","basic-user-avatars")."</strong> ' . esc_attr( $avatar['error'] ) . '");' ) );
						}
						return;
					}
					
					$imagedetails = $imagedetails = getimagesize($avatar['url']);
					$width = $imagedetails[0];
					$height = $imagedetails[1]; 
					if ($width > 250 && $height > 250 ) {
						wp_die(__('Yüklediğiniz avatarın boyutu maksimum 250px genişiğinde ve maksimum 250px yüksekliğinde olmalıdır.', 'kanews'));
						return;
					}
					
					// Delete old images if successful
					$this->avatar_delete( $user_id );
					
					update_user_meta( $user_id, 'basic_user_avatar', array( 'full' => $avatar['url'] ) );
				
					}
					else {
						wp_die(__('Yüklemeye çalıştığınız dosya uzantısı kabul edilmemektedir. Sadece jpg, jpeg ve png uzantılı dosya yükleyebilirsiniz.', 'kanews'));
					}
				} elseif ( ! empty( $_POST['basic-user-avatar-erase'] ) ) {
					
				// Nuke the current avatar
				$this->avatar_delete( $user_id );
				
				
				
				}
		}

		/**
		* Enable avatar management on the frontend via this shortocde.
		*
		* @since 1.0.0
		*/
		function shortcode() {

			// Don't bother if the user isn't logged in
			if ( ! is_user_logged_in() )
				return;

			$user_id     = get_current_user_id();
			$profileuser = get_userdata( $user_id );

			if ( isset( $_POST['manage_avatar_submit'] ) ){
				$this->edit_user_profile_update( $user_id );
			}

			ob_start();
			?>
			<form id="basic-user-avatar-form" action="<?php the_permalink(); ?>" method="post" enctype="multipart/form-data">
				<?php
				echo get_avatar( $profileuser->ID );

				$options = get_option( 'basic_user_avatars_caps' );
				if ( empty( $options['basic_user_avatars_caps'] ) || current_user_can( 'upload_files' ) ) {
					// Nonce security ftw
					wp_nonce_field( 'basic_user_avatar_nonce', '_basic_user_avatar_nonce', false );
					
					// File upload input
					echo '<p><input type="file" name="basic-user-avatar" id="basic-local-avatar" /></p>';

					if ( empty( $profileuser->basic_user_avatar ) ) {
						echo '<p class="description">' . __( 'No local avatar is set. Use the upload field to add a local avatar.', 'kanews' ) . '</p>';
					} else {
						echo '<input type="checkbox" name="basic-user-avatar-erase" value="1" /> ' . __( 'Delete local avatar', 'kanews' ) . '<br />';
						echo '<p class="description">' . __( 'Replace the local avatar by uploading a new avatar, or erase the local avatar (falling back to a gravatar) by checking the delete option.', 'kanews' ) . '</p>';
					}

				} else {
					if ( empty( $profileuser->basic_user_avatar ) ) {
						echo '<p class="description">' . __( 'No local avatar is set. Set up your avatar at Gravatar.com.', 'kanews' ) . '</p>';
					} else {
						echo '<p class="description">' . __( 'You do not have media management permissions. To change your local avatar, contact the site administrator.', 'kanews' ) . '</p>';
					}	
				}
				?>
				<input type="submit" name="manage_avatar_submit" value="<?php _e( 'Update Avatar', 'kanews' ); ?>" />
			</form>
			<?php
			return ob_get_clean();
		}

		/**
		* Form to display on the bbPress user profile edit screen
		*
		* @since 1.0.0
		*/
		public function bbpress_user_profile() {

			if ( !bbp_is_user_home_edit() )
				return;

			$user_id     = get_current_user_id();
			$profileuser = get_userdata( $user_id );

			echo '<div>';
				echo '<label for="basic-local-avatar">' . __( 'Avatar', 'kanews' ) . '</label>';
				echo '<fieldset class="bbp-form avatar">';

					echo get_avatar( $profileuser->ID );
					$options = get_option( 'basic_user_avatars_caps' );
					if ( empty( $options['basic_user_avatars_caps'] ) || current_user_can( 'upload_files' ) ) {
						// Nonce security ftw
						wp_nonce_field( 'basic_user_avatar_nonce', '_basic_user_avatar_nonce', false );
						
						// File upload input
						echo '<br /><input type="file" name="basic-user-avatar" id="basic-local-avatar" /><br />';

						if ( empty( $profileuser->basic_user_avatar ) ) {
							echo '<span class="description" style="margin-left:0;">' . __( 'No local avatar is set. Use the upload field to add a local avatar.', 'kanews' ) . '</span>';
						} else {
							echo '<input type="checkbox" name="basic-user-avatar-erase" value="1" style="width:auto" /> ' . __( 'Delete local avatar', 'kanews' ) . '<br />';
							echo '<span class="description" style="margin-left:0;">' . __( 'Replace the local avatar by uploading a new avatar, or erase the local avatar (falling back to a gravatar) by checking the delete option.', 'kanews' ) . '</span>';
						}

					} else {
						if ( empty( $profileuser->basic_user_avatar ) ) {
							echo '<span class="description" style="margin-left:0;">' . __( 'No local avatar is set. Set up your avatar at Gravatar.com.', 'kanews' ) . '</span>';
						} else {
							echo '<span class="description" style="margin-left:0;">' . __( 'You do not have media management permissions. To change your local avatar, contact the site administrator.', 'kanews' ) . '</span>';
						}	
					}

				echo '</fieldset>';
			echo '</div>';
			?>
			<script type="text/javascript">var form = document.getElementById('bbp-your-profile');form.encoding = 'multipart/form-data';form.setAttribute('enctype', 'multipart/form-data');</script>
			<?php
		}

		/**
		* Remove the custom get_avatar hook for the default avatar list output on 
		* the Discussion Settings page.
		*
		* @since 1.0.0
		* @param array $avatar_defaults
		* @return array
		*/
		public function avatar_defaults( $avatar_defaults ) {
			remove_action( 'get_avatar', array( $this, 'get_avatar' ) );
			return $avatar_defaults;
		}

		/**
		* Delete avatars based on user_id
		*
		* @since 1.0.0
		* @param int $user_id
		*/
		public function avatar_delete( $user_id ) {
			$old_avatars = get_user_meta( $user_id, 'basic_user_avatar', true );
			$upload_path = wp_upload_dir();

			if ( is_array( $old_avatars ) ) {
				foreach ( $old_avatars as $old_avatar ) {
					$old_avatar_path = str_replace( $upload_path['baseurl'], $upload_path['basedir'], $old_avatar );
					@unlink( $old_avatar_path );
				}
			}

			delete_user_meta( $user_id, 'basic_user_avatar' );
		}

		/**
		* File names are magic
		*
		* @since 1.0.0
		* @param string $dir
		* @param string $name
		* @param string $ext
		* @return string
		*/
		public function unique_filename_callback( $dir, $name, $ext ) {
			$user = get_user_by( 'id', (int) $this->user_id_being_edited );
			$name = $base_name = sanitize_file_name( $user->display_name . '_avatar' );
			$number = 1;

			while ( file_exists( $dir . "/$name$ext" ) ) {
				$name = $base_name . '_' . $number;
				$number++;
			}

			return $name . $ext;
		}

		public function possibly_redirect(){
			$page = kanews_get_option('account-page') ? kanews_get_option('account-page') : '';
			if (kanews_get_option('wp-admin-redirect') == true && $page != '' && kanews__get__status() == true) {
				global $pagenow;
				if( 'wp-login.php' == $pagenow ) {
					if ( isset( $_POST['wp-submit'] ) ||   // in case of LOGIN
						( isset($_GET['action']) && $_GET['action']=='logout') ||   // in case of LOGOUT
						( isset($_GET['checkemail']) && $_GET['checkemail']=='confirm') ||   // in case of LOST PASSWORD
						( isset($_GET['checkemail']) && $_GET['checkemail']=='registered') ||    // in case of REGISTER
						( isset($_GET['action']) == 'lostpassword') ) return;
					else wp_redirect(home_url());
					exit();
				}
			}
		}

		public function save_user_profile_fields( $user_id) {
			update_user_meta( $user_id,'facebook_profile', sanitize_text_field( $_POST['facebook_profile'] ) );
			update_user_meta( $user_id,'twitter_profile', sanitize_text_field( $_POST['twitter_profile'] ) );
			update_user_meta( $user_id,'instagram_profile', sanitize_text_field( $_POST['instagram_profile'] ) );
			update_user_meta( $user_id,'linkedin_profile', sanitize_text_field( $_POST['linkedin_profile'] ) );
			update_user_meta( $user_id,'youtube_profile', sanitize_text_field( $_POST['youtube_profile'] ) ); 
		}

		public function add_user_profile_fields( $user, $false = 'on' ) { if(is_admin()): ?>
			<table class="form-table">
				<tr>
					<th><label for="facebook_profile"><?php _e('Facebook Kullanıcı Adınız','kanews'); ?></label></th>
					<td>
						<input type="text" name="facebook_profile" value="<?php echo esc_attr(get_the_author_meta( 'facebook_profile', $user->ID )); ?>" class="regular-text" />
					</td>
				</tr>
				<tr>
					<th><label for="twitter_profile"><?php _e('Twitter Kullanıcı Adınız','kanews'); ?></label></th>
					<td>
						<input type="text" name="twitter_profile" value="<?php echo esc_attr(get_the_author_meta( 'twitter_profile', $user->ID )); ?>" class="regular-text" />
					</td>
				</tr>
				<tr>
					<th><label for="instagram_profile"><?php _e('Instagram Kullanıcı Adınız','kanews'); ?></label></th>
					<td>
						<input type="text" name="instagram_profile" value="<?php echo esc_attr(get_the_author_meta( 'instagram_profile', $user->ID )); ?>" class="regular-text" />
					</td>
				</tr>
				<tr>
					<th><label for="linkedin_profile"><?php _e('Linkedin Kullanıcı Adınız','kanews'); ?></label></th>
					<td>
						<input type="text" name="linkedin_profile" value="<?php echo esc_attr(get_the_author_meta( 'linkedin_profile', $user->ID )); ?>" class="regular-text" />
					</td>
				</tr>
				<tr>
					<th><label for="youtube_profile"><?php _e('Youtube Kanal idsi','kanews'); ?></label></th>
					<td>
						<input type="text" name="youtube_profile" value="<?php echo esc_attr(get_the_author_meta( 'youtube_profile', $user->ID )); ?>" class="regular-text" />
					</td>
				</tr>
			</table>
		<?php endif; }

  }
  
  $KANEWS_MEMBERSHIP = new KANEWS_MEMBERSHIP();
}

/*-----------------------------------------------------------------------------------*/
# Account Page URL
/*-----------------------------------------------------------------------------------*/
function kanews_account_page_url($register = NULL) {
  $page = kanews_get_option('account-page') ? kanews_get_option('account-page') : '';
  
  if($page == '') {
    if($register == true) {
      $out = wp_registration_url();
    } else {
      $out = wp_login_url();
    }
  } else { 
		if($register == true)
			$out = get_page_link($page).'?islem=kayit';
		else 
			$out = get_page_link($page);
  }
  return $out;
}

/*-----------------------------------------------------------------------------------*/
# Header User Btn
/*-----------------------------------------------------------------------------------*/
function kanews_header_user_btn() {

  if(kanews_get_option('login-user-button') == false && kanews_get_option('login-system') == false)
  return;

  if(is_user_logged_in()) {
    $current_user = wp_get_current_user();
    $current_user_id = get_current_user_id();
    $avatar = kanews_user_avatar($current_user_id, 38);
    echo '<div class="kanews-dropdown">';
      echo '<button data-toggle="kanews-user-dropdown">'.$avatar.'</button>';
      echo '<div id="kanews-user-dropdown" class="kanews-dropdown-content">';
        echo '<ul>';
          echo '<li class="kanews-dropdown-title">'.sprintf(esc_html__( 'Hoşgeldin, %s','kanews'), $current_user->display_name).'</li>';
          if ( current_user_can('administrator') )
					echo '<li><a href="'.site_url().'/wp-admin">'.esc_html__('Yönetici Paneli', 'kanews').'</a></li>';
					$page = kanews_get_option('account-page') ? kanews_get_option('account-page') : '';
					if($page != '')
					echo '<li><a href="'.kanews_account_page_url().'">'.esc_html__( 'Hesabım', 'kanews' ).'</a></li>';
					if(kanews_get_option('feed-page') != '')
          echo '<li><a href="'.get_page_link(kanews_get_option('feed-page')).'">'.esc_html__( 'Akışım', 'kanews' ).'</a></li>';
          echo '<li><a href="'.wp_logout_url( home_url( add_query_arg( [], $GLOBALS['wp']->request ) ) ).'">'.esc_html__('Çıkış Yap', 'kanews').'</a></li>';
        echo '</ul>';
      echo '</div>';
    echo '</div>';
  } else {
    echo '<button data-toggle="kanews-modal-login" class="header-btn-icon"><i class="icon-user icon-2x"></i></button>';
  }

}

/*-----------------------------------------------------------------------------------*/
# Login Modal
/*-----------------------------------------------------------------------------------*/
function kanews_login_modal() {

  if(kanews_get_option('login-system') != true || is_user_logged_in())
  return;

  echo '<div id="kanews-modal-login" class="kanews-modal kanews-modal-login">';
    echo '<div data-toggle="kanews-modal-login" class="kanews-modal-close"></div>';
    echo '<div class="kanews-modal-content">';
      echo '<div class="kanews-modal-title">'.esc_html__( 'Giriş Yap', 'kanews' ).'</div>';
      echo '<div data-toggle="kanews-modal-login" class="kanews-modal-close-btn"><i class="icon-close"></i></div>';
      echo '<div class="kanews-modal-content-inner">';
        echo '<p>'.kanews_translate('login-description', sprintf( esc_html__('%s ayrıcalıklarındandan yararlanmak için hemen giriş yapın veya hesap oluşturun, üstelik tamamen ücretsiz!', 'kanews' ), get_bloginfo( 'name' ))).'</p>';
        echo '<div class="kanews-btn-group">';
          echo '<a href="'.kanews_account_page_url().'" class="kanews-btn">'.esc_html__( 'Giriş Yap', 'kanews' ).'</a>';
          echo '<a href="'.kanews_account_page_url(true).'" class="kanews-btn bg-dark">'.esc_html__( 'Kayıt Ol', 'kanews' ).'</a>';
        echo '</div>';
      echo '</div>';
    echo '</div>';
  echo '</div>';

}

function user_badge($author) {
	$user = new WP_User( $author );
	$role = $user->roles;
	$badges = kanews_get_option('user-badge');
	$out = '';
	if (!empty($badges)){
		foreach($badges as $badge) {
			if ( isset($badge['title']) && !empty($badge['title']) && !empty($badge['role']) && isset($badge['role'])) {
				if($role[0] == $badge['role']){
					$out .= '<span class="kanews-user-badge"><span style="background-color: '.$badge['color'].'" class="user-rank-geo">'.$badge['title'].'</span></span>';
				}
			}
		}
	}
	
	
	return $out;
}