<?php

class SuperLigStandings
{


    /**
     * This function return Team Names
     * Returned values are name,middleName,ShortName
     * @return Team Array
     */
    public function getTeamNames(){
        $teamNames = array();
        foreach ($this->getData($league) as $data) {
            $team = new Team();
            $team->name = $data->name;
            $team->middleName = $data->middleName;
            $team->shortName = $data->shortName;
            array_push($teamNames,$team);
        }
        return $teamNames;
    }

    /**
     * This function return Simple fixture data
     * Returned values are name,shortName,position,points
     * @return Team Array
     */
    public function getSimpleStandings(){
        $standings = array();
        foreach ($this->getData($league) as $data) {
            $team = new Team();
            $team->name = $data->name;
            $team->played = $data->played;
            $team->position = $data->position;
            $team->points = $data->points;
            array_push($standings,$team);
        }
        return $standings;
    }

    /**
     * This function return SuperLig Fixture
     * Returned values are name,middleName,shortName,position,points,against,average,lost,won,played,logo
     * @return Team Array
     */
    public function getStandings($league){
        $standings = array();
        foreach ($this->getData($league) as $data) {
            $team = new Team();
            $team->name = $data->name;
            $team->middleName = $data->middleName;
            $team->shortName = $data->shortName;
            $team->position = $data->position;
            $team->position_status = $data->positionStatus->name;
            $team->points = $data->points;
            $team->against = $data->against;
            $team->average = $data->average;
            $team->drawn = $data->drawn;
            $team->lost = $data->lost;
            $team->played = $data->played;
            $team->won = $data->won;
            $team->form = $data->formStatus;
            $team->delta = $data->delta;
            $team->logo = $this->generateTeamLogo($data->id);
            array_push($standings,$team);
        }
        return $standings;
    }

    /**
     * @param $teamId
     * This function generate team logo url
     * @return Team logo url
     */
    private function generateTeamLogo($teamId){
        return  "https://cdn.broadage.com/images-teams/soccer/18x18/{$teamId}.png";
    }

    /**
     *This function get data from ntvspor
     */
    private function getData($league){
        $args = array(
            'timeout' => '25',
            'sslverify' => false
        );
        $response = wp_remote_get(KAN_TEMPLATE_URL."/inc/api/standings/".$league.".json", $args);
        $body = wp_remote_retrieve_body( $response );
        $data = json_decode($body)->data->initialData[0];
        return $data;
    }
}

class Team{
    public $name;
    public $middleName;
    public $shortName;
    public $points;
    public $average;
    public $against;
    public $scored;
    public $lost;
    public $drawn;
    public $won;
    public $played;
    public $position;
    public $delta;
    public $position_status;
    public $logo;
}
