<?php

/*-----------------------------------------------------------------------------------*/
# Theme Option
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_get_option' ) ) {
	function kanews_get_option( $option = '', $default = null ) {
	  $options = get_option( 'kanews_options' );
	  return ( isset( $options[$option] ) ) ? $options[$option] : $default;
	}
}

/*-----------------------------------------------------------------------------------*/
# Lazy Load for entry images
/*-----------------------------------------------------------------------------------*/

function add_image_placeholders( $content ) {
	// Don't lazyload for feeds, previews, mobile
	if( is_feed() || is_preview() || !is_singular() || kanews_get_option('lazy') == false || (function_exists( 'is_amp_page' ) && is_amp_page()) || ( function_exists( 'is_amp_endpoint' ) && is_amp_endpoint()))
		return $content;

	// Don't lazy-load if the content has already been run through previously
	if ( false !== strpos( $content, 'data-src' ) )
		return $content;

	// In case you want to change the placeholder image
	$placeholder_image = apply_filters( 'lazyload_images_placeholder_image', 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAG4AAABLAQMAAACr9CA9AAAAA1BMVEX///+nxBvIAAAAAXRSTlMAQObYZgAAABZJREFUOI1jYMADmEe5o9xR7iiXQi4A4BsA388WUyMAAAAASUVORK5CYII=' );

	// This is a pretty simple regex, but it works
	$content = preg_replace( '#<img([^>]+?)src=[\'"]?([^\'"\s>]+)[\'"]?([^>]*)>#', sprintf( '<img${1}src="%s" data-src="${2}"${3}><noscript><img${1}src="${2}"${3}></noscript>', $placeholder_image ), $content );
	$content = str_replace('srcset="', 'data-srcset="', $content); 
	
	return $content;
}


/*-----------------------------------------------------------------------------------*/
# Lazy load for featured images
/*-----------------------------------------------------------------------------------*/
function wpse8170_add_lazyload_to_attachment_image( $attr, $attachment ) {
	if( is_admin() || is_preview() || kanews_get_option('lazy') == false  || (function_exists( 'is_amp_page' ) && is_amp_page()) || ( function_exists( 'is_amp_endpoint' ) && is_amp_endpoint())) {
		return $attr;
	}
	$attr['class'] .= ' kanews-lazy';  
	$attr['data-src'] = $attr['src'];
	if (!empty($attr['srcset'])) {
		$attr['data-srcset'] = $attr['srcset'];
	}
	
	$attr['src'] = kanews_lazy_link();
	$size = explode(" ", $attr['class']);
	foreach($size as $sa) {
		if($sa == 'size-kanews-post-4') {
			$attr['src'] = kanews_lazy_link2();
			break;
		}
	}
	
	
	if (!empty($attr['data-srcset'])) {
		$attr['srcset'] = kanews_lazy_link().' 850w';
	}
  return $attr;
}

/*-----------------------------------------------------------------------------------*/
# Header Center
/*-----------------------------------------------------------------------------------*/
function kanews_header_center_module() {
	$option = kanews_get_option('header-center');
	$currencies = (kanews_get_option('header-center-currencies') != '') ? kanews_get_option('header-center-currencies') : '';
	switch($option) {
		case 'covid':
			echo kanews_header_covid();
		break;
		case 'covid-daily':
			echo kanews_header_covid_daily();
		break;
		case 'search':
			echo kanews_header_search_form('style1');
		break;
		case 'currencies': ?>
			<div class="site-currencies"><div class="d-flex"><?php KANEWS_CURRENCIES::get_currencies($currencies, false); ?></div></div>
		<?php break;
	}
}

/*-----------------------------------------------------------------------------------*/
# SubHeader Left Modules
/*-----------------------------------------------------------------------------------*/
function kanews_subheader_left_module() {
	$option = kanews_get_option('subheader-left');
	$currencies = (kanews_get_option('subheader-left-currencies') != '') ? kanews_get_option('subheader-left-currencies') : '';

	switch($option) {
		case 'currencies': ?>
			<div class="site-currencies"><div class="d-flex"><?php KANEWS_CURRENCIES::get_currencies($currencies, false); ?></div></div>
			<?php break;
		case 'breaking-news': 
			$cats     = (!empty(kanews_get_option('subheader-left-bn-cats'))) ? kanews_get_option('subheader-left-bn-cats') : 'all';
			$excluded = (!empty(kanews_get_option('subheader-left-bn-post-not-in'))) ? kanews_get_option('subheader-left-bn-post-not-in') : '';
			$count    = (!empty(kanews_get_option('subheader-left-bn-count'))) ? kanews_get_option('subheader-left-bn-count') : '5';
			$sortby    = kanews_get_option('subheader-left-bn-sortby') == 'recent' ? 'DESC' : 'modified';
			$title    = (!empty(kanews_get_option('breaking-new-text'))) ? kanews_get_option('breaking-new-text') : esc_html__( 'Son Gelişmeler', 'kanews' );
			$query = new WP_Query(
				array( 
					'cat'          => $cats,
					'showposts'    => $count,
					'orderby'      => $sortby,
					'post__not_in' => $excluded
				)
			);
			?>
			<?php kanews_breaking_news_ticker($title, $query, true, true, $sortby ); ?>
		<?php break; case 'menu': ?>
			<div class="site-subheader-menu">
				<?php if ( has_nav_menu( 'subheader-left' ) ) :
					wp_nav_menu( array(
						'theme_location' => 'subheader-left',
						'menu_class'     => 'd-flex',
						'depth'     		 => '1',
						'container'      => false,
					));
				else: ?>
					<ul class="d-flex"><li><a href="<?php echo admin_url( 'nav-menus.php' ); ?>"><?php esc_html_e( 'Menü Oluştur', 'kanews' ); ?></a></li></ul>
				<?php endif; ?>
			</div>
		<?php break;
		case 'weather': ?>
			<div data-toggle="kanews-weather-select-city" class="kanews-city-weather" data-city="<?php if(kanews_get_option('subheader-weather-city') != ''): echo kanews_get_option('subheader-weather-city'); else: ?>İstanbul<?php endif;?>"></div>
			<?php echo kanews_get_turkey_cities('kanews-weather-select-city'); ?>
		<?php break; 
	}
}

/*-----------------------------------------------------------------------------------*/
# SubHeader Right Modules
/*-----------------------------------------------------------------------------------*/
function kanews_subheader_right_module() {
	$option = kanews_get_option('subheader-right');
	$currencies = (kanews_get_option('subheader-right-currencies') != '') ? kanews_get_option('subheader-right-currencies') : '';

	switch($option) {
		case 'currencies': ?>
			<div class="site-currencies"><div class="d-flex"><?php KANEWS_CURRENCIES::get_currencies($currencies, false); ?></div></div>
			<?php break;
		case 'menu': ?>
			<div class="site-subheader-menu">
				<?php if ( has_nav_menu( 'subheader-right' ) ) :
					wp_nav_menu( array(
						'theme_location' => 'subheader-right',
						'menu_class'     => 'd-flex',
						'depth'     		 => '1',
						'container'      => false,
					));
				else: ?>
					<ul class="d-flex"><li><a href="<?php echo admin_url( 'nav-menus.php' ); ?>"><?php esc_html_e( 'Menü Oluştur', 'kanews' ); ?></a></li></ul>
				<?php endif; ?>
			</div>
		<?php break;
		case 'weather': ?>
			<div data-toggle="kanews-weather-select-city2" class="kanews-city-weather" data-city="<?php if(kanews_get_option('subheader-weather-city2') != ''): echo kanews_get_option('subheader-weather-city2'); else: ?>İstanbul<?php endif;?>"></div>
			<?php echo kanews_get_turkey_cities('kanews-weather-select-city2'); ?>
		<?php break; 
	}
}

/*-----------------------------------------------------------------------------------*/
# Page Builder
/*-----------------------------------------------------------------------------------*/
function kanews_mobile_menu() {
	$copyright = !empty(kanews_get_option('mobile-menu-footer-text')) ? kanews_get_option('mobile-menu-footer-text') : '';
	// Search
	$search = '<div class="site-mobile-menu-header"><form id="search-autocomplete" role="search" method="get" action="' . esc_url( home_url( '/' ) ) . '">
		<input class="search-autocomplete" type="text" placeholder="' . esc_html__( 'Aramak istediğiniz kelimeyi yazın..', 'kanews' ).'" value="' . get_search_query() . '" name="s" />
	</form></div>';
	$args = array(
		'theme_location' => 'menu-2',
		'container_class'=> 'site-mobile-menu-nav',
		'depth'     		 => 3,
	);
	?>
	<div id="site-mobile-menu">
		<div class="site-mobile-menu-overlay" data-toggle="site-mobile-menu"></div>
		<div class="site-mobile-menu-wrapper">
			<?php if(kanews_get_option('mobile-menu-search') != false) echo $search; ?>
			<?php if ( has_nav_menu( 'menu-2' ) ) : ?>
				<?php wp_nav_menu( $args ); ?>
			<?php endif; ?>
			<?php if($copyright != ''): ?>
				<div class="site-mobile-menu-footer">
					<?php if(kanews_get_option('kanews-insights') == true && kanews_get_option('kanews-insights-button') == true && kanews_insights_control() == false): ?>
						<a href="<?php echo kanews_insights_page_url(); ?>" class="kanews-btn kanews-btn-sm"><?php esc_html_e( 'Abone Ol', 'kanews' ); ?></a>
					<?php endif; ?>
					<?php echo kanews_dark_mode_button(); ?>
					<?php 
						$footer_vars = array( '%year%', '%site%', '%url%' );
						$footer_val  = array( date('Y') , get_bloginfo('name') , esc_url(home_url( '/' )) );
						echo '<p>'. str_replace( $footer_vars , $footer_val , $copyright) . '</p>'; 
					?>
				</div>
			<?php endif; ?>
		</div>
	</div>
	<?php 
}

/*-----------------------------------------------------------------------------------*/
# Home Archives
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_recent_posts' ) ) {
	function kanews_recent_posts($loc, $title = '', $htag = 'h4') {
		$style = (kanews_get_option($loc.'-recent-post-style') != '') ? kanews_get_option($loc.'-recent-post-style') : '1';
		$count = 0;
		if ($style == 'disable')
		return;
		$flat = '';
		if ($style == '3' || $style == '2')
		$flat = 'kanews-section-flat';
		echo '<div class="col-12">';
			echo '<div class="kanews-section '.$flat.' kanews-posts-style-'.$style.' ">';
				echo kanews_widget_title($title, $htag);
				if ( have_posts() ) : 
					echo '<div class="row" kanews-data-load-more>';
						while ( have_posts() ) : the_post(); $counter++;
							get_template_part('template-parts/archives/article', $style);
							KANEWS_ADVERTISEMENT::ad_archives($style, $counter);
						endwhile;
					echo '</div>';
					kanews_pagination();
				else:
					get_template_part('template-parts/archives/article', 'none');
				endif;
			echo '</div>';
		echo '</div>';
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Home Top Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_home_page_top' ) ) {
	function kanews_home_page_top() {
		if ( is_home() && ! is_paged() ) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-top-full' );
			echo '</div>';
		} 
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Home Bottom Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_home_page_bottom' ) ) {
	function kanews_home_page_bottom() {
		if ( is_home() && ! is_paged() ) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-bottom-full' );
			echo '</div>';
		} 
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Home Content
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_home_page_content_start' ) ) {
	function kanews_home_page_content_start() {
		echo '<div class="kanews-widget-area kanews-widgets-content">';
	}
}	
if ( ! function_exists( 'kanews_home_page_content_end' ) ) {
	function kanews_home_page_content_end() {
		echo '</div>';
	}
}	

if ( ! function_exists( 'kanews_home_page_content' ) ) {
	function kanews_home_page_content() {
		echo '<div class="col-12 col-lg-8 kanews-sticky">';
			echo '<div class="row">';
				dynamic_sidebar( 'home-content' );
				$title = (kanews_get_option('home-recent-post-title')) ? kanews_get_option('home-recent-post-title') : '';
				kanews_recent_posts('home', $title);
			echo '</div>';
		echo '</div>';
	}
}

if ( ! function_exists( 'kanews_home_page_sidebar' ) ) {
	function kanews_home_page_sidebar() {
		echo '<div class="col-12 col-lg-4 kanews-sticky">';
			echo '<div class="row" role="complementary">';
				dynamic_sidebar( 'home-sidebar' );
			echo '</div>';
		echo '</div>';
	} 
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Cat Top Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_cat_page_top' ) ) {
	function kanews_cat_page_top() {
		$category = get_category(get_query_var('cat'),false);
		$category = $category->slug;
		if(category_description($category)) {
			echo '<article class="kanews-section kanews-section-flat"><div class="col-12">'.category_description($category).'</div></article>';
		}
		if ( ! is_paged() && is_active_sidebar( 'home-top-full-'.$category ) ) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-top-full-'.$category );
			echo '</div>';
		} elseif(!is_paged()) {
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'category-top-full' );
			echo '</div>';
		}
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Cat Bottom Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_cat_page_bottom' ) ) {
	function kanews_cat_page_bottom() {
		$category = get_category(get_query_var('cat'),false);
		$category = $category->slug;
		if ( ! is_paged() && is_active_sidebar( 'home-top-full-'.$category  )) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-bottom-full-'.$category );
			echo '</div>';
		} 
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Cat Content
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_cat_page_content_start' ) ) {
	function kanews_cat_page_content_start() {
		echo '<div class="kanews-widget-area kanews-widgets-content">';
	}
}	
if ( ! function_exists( 'kanews_cat_page_content_end' ) ) {
	function kanews_cat_page_content_end() {
		echo '</div>';
	}
}	

if ( ! function_exists( 'kanews_cat_page_content' ) ) {
	function kanews_cat_page_content() {
		$category = get_category(get_query_var('cat'),false);
		$category = $category->slug;
		echo '<div class="col-12 col-lg-8 kanews-sticky">';
			echo '<div class="row">';
				if ( ! is_paged() && is_active_sidebar( 'home-content-'.$category ) ) { 
					dynamic_sidebar( 'home-content-'.$category );
				}elseif(!is_paged() && is_active_sidebar('category-content')) {
					dynamic_sidebar( 'category-content' );
				}
				$title = single_cat_title('', false);
				kanews_recent_posts('cat', $title);
			echo '</div>';
		echo '</div>';
	}
}

if ( ! function_exists( 'kanews_cat_page_sidebar' ) ) {
	function kanews_cat_page_sidebar() {
		$category = get_category(get_query_var('cat'),false);
		$category = $category->slug;
		echo '<div class="col-12 col-lg-4 kanews-sticky">';
			echo '<div class="row" role="complementary">';
				if(is_active_sidebar( 'home-sidebar-'.$category ) ) {
					dynamic_sidebar( 'home-sidebar-'.$category );
				} else {
					dynamic_sidebar( 'home-sidebar-cat' );
				}
			echo '</div>';
		echo '</div>';
	} 
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Page Top Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_custom_page_top' ) ) {
	function kanews_custom_page_top() {
		$category = get_queried_object_id();
		if ( is_active_sidebar( 'home-top-full-'.$category ) ) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-top-full-'.$category );
			echo '</div>';
		} 
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Page Bottom Full
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_custom_page_bottom' ) ) {
	function kanews_custom_page_bottom() {
		$category = get_queried_object_id();
		if ( is_active_sidebar( 'home-top-full-'.$category  )) { 
			echo '<div class="kanews-widget-area kanews-widgets-top">';
				dynamic_sidebar( 'home-bottom-full-'.$category );
			echo '</div>';
		} 
	}
}

/*-----------------------------------------------------------------------------------*/
# Widget Area: Page Content
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_custom_page_content_start' ) ) {
	function kanews_custom_page_content_start() {
		echo '<div class="kanews-widget-area kanews-widgets-content">';
	}
}	
if ( ! function_exists( 'kanews_custom_page_content_end' ) ) {
	function kanews_custom_page_content_end() {
		echo '</div>';
	}
}	

if ( ! function_exists( 'kanews_custom_page_content' ) ) {
	function kanews_custom_page_content() {
		$category = get_queried_object_id();
		if ( is_active_sidebar( 'home-content-'.$category ) ) { 
			echo '<div class="col-12 col-lg-8 kanews-sticky">';
				echo '<div class="row">';
				dynamic_sidebar( 'home-content-'.$category );
				echo '</div>';
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'kanews_custom_page_sidebar' ) ) {
	function kanews_custom_page_sidebar() {
		$category = get_queried_object_id();
		if(is_active_sidebar( 'home-sidebar-'.$category ) ) {
			echo '<div class="col-12 col-lg-4 kanews-sticky">';
				echo '<div class="row" role="complementary">';
					
					dynamic_sidebar( 'home-sidebar-'.$category );
	
				echo '</div>';
			echo '</div>';
		}
	} 
}

/*-----------------------------------------------------------------------------------*/
# Entry Header
/*-----------------------------------------------------------------------------------*/
function kanews_entry_header($video = NULL){ 
	$pid = get_the_ID();
	$default_options = [
		'excerpt'     => (kanews_get_option('show-post-excerpt') == false) ? false : true,
		'cat' 				=> (kanews_get_option('show-post-cat') == false) ? false : true,
		'author' 			=> (kanews_get_option('show-post-author') == false) ? false : true,
		'date' 				=> (kanews_get_option('show-post-date') == false) ? false : true,
		'update-date' => (kanews_get_option('show-post-update-date') == false) ? false : true,
		'post-views'  => (kanews_get_option('show-post-views') == false) ? false : true,
		'reading-time'=> (kanews_get_option('show-post-reading-time') == false) ? false : true,
		'show-more'   => (kanews_get_option('show-post-more') == false) ? false : true
	];
	$single_options = [
		'excerpt-text'     => get_post_meta( $pid, 'kanews_post_excerpt', true ),
		'excerpt'     => get_post_meta( $pid, 'show_post_excerpt', true ),
		'cat'			    => get_post_meta( $pid, 'show_post_cat', true ),
		'author' 			=> get_post_meta( $pid, 'show_post_author', true ),
		'date' 			  => get_post_meta( $pid, 'show_post_date', true ),
		'update-date' => get_post_meta( $pid, 'show_post_update_date', true ),
		'post-views'  => get_post_meta( $pid, 'show_post_views', true ),
		'reading-time'=> get_post_meta( $pid, 'show_post_read_time', true ),
		'show-more'		=> get_post_meta( $pid, 'show_post_more', true ),
	];
	?>
	<div class="kanews-article-header">
		<?php if($video != true): ?>
			<?php kanews_breadcrumb($pid); ?>
		<?php endif; ?>
		<?php the_title( '<h1 class="kanews-article-title">', '</h1>' ); ?>
		<?php if($single_options['excerpt'] == 'on' && $single_options['exceprt-text'] != '' ): ?>
			<p><?php echo $single_options['excerpt-text']; ?></p>
		<?php elseif($single_options['excerpt'] != 'off' && $default_options['excerpt'] != false && $single_options['excerpt-text'] != ''  ): ?>
			<p><?php echo $single_options['excerpt-text']; ?></p>
		<?php endif; ?>
		<div class="kanews-article-meta">
			<div class="row justify-content-between align-items-center">
				<div class="kanews-article-meta-left col-12 col-lg">
					<?php if($single_options['author'] == 'on' ): ?>
						<?php kanews_posted_by('with-avatar'); ?>
					<?php elseif($single_options['author'] != 'off' && $default_options['author'] != false  ): ?>
						<?php kanews_posted_by('with-avatar'); ?>
					<?php endif; ?>

					<?php if($single_options['date'] == 'on' ): ?>
						<?php kanews_posted_on(); ?>
					<?php elseif($single_options['date'] != 'off' && $default_options['date'] != false  ): ?>
						<?php kanews_posted_on(); ?>
					<?php endif; ?>
				</div>
				<div class="kanews-article-meta-right col-12 col-lg-auto">
					<?php if($single_options['update-date'] == 'on' ): ?>
						<?php kanews_post_updated(); ?>
					<?php elseif($single_options['update-date'] != 'off' && $default_options['update-date'] != false  ): ?>
						<?php kanews_post_updated(); ?>
					<?php endif; ?>
					<?php if($single_options['reading-time'] == 'on' ): ?>
						<?php kanews_post_reading_time(get_post($pid)); ?>
					<?php elseif($single_options['reading-time'] != 'off' && $default_options['reading-time'] != false  ): ?>
						<?php kanews_post_reading_time(get_post($pid)); ?>
					<?php endif; ?>
					<?php if($single_options['post-views'] == 'on' ): ?>
						<?php echo kanews_get_post_views($pid, '', true, true); ?>
					<?php elseif($single_options['post-views'] != 'off' && $default_options['post-views'] != false  ): ?>
						<?php echo kanews_get_post_views($pid, '', true, true); ?>
					<?php endif; ?>
				</div>
			</div>
		</div>
		<?php do_action('kanews_entry_meta_below'); ?>
		<?php if($video == true): ?>
			<?php if($single_options['show-more'] == 'on' ): ?>
				<a href="javascript:void(0);" class="kanews-show-more-button kanews-label"><?php esc_html_e( 'Daha Fazla Göster', 'kanews' ); ?></a>
			<?php elseif($single_options['show-more'] != 'off' && $default_options['show-more'] != false  ): ?>
				<a href="javascript:void(0);" class="kanews-show-more-button kanews-label"><?php esc_html_e( 'Daha Fazla Göster', 'kanews' ); ?></a>
			<?php endif; ?>
		<?php endif; ?>
		
	</div>
<?php }

/*-----------------------------------------------------------------------------------*/
# Entry Assets
/*-----------------------------------------------------------------------------------*/
function kanews_entry_assets(){ 
	$pid = get_the_ID();
	$default_options = [
		'post-like'  => (kanews_get_option('post-like') == false) ? false : true,
		'post-share'  => (kanews_get_option('show-post-share') == false) ? false : true,
		'post-assets' => (kanews_get_option('show-post-assets') == false) ? false : true,
	];
	$single_options = [
		'post-share'  => get_post_meta( $pid, 'show_post_share', true ),
		'post-like'  => get_post_meta( $pid, 'show_post_like', true ),
		'post-assets' => get_post_meta( $pid, 'show_post_assets', true ),
	]; ?>


	<div class="kanews-article-action">
		<div class="row justift-content-between align-items-center">
			<div class="kanews-article-action-left col-12 col-lg d-flex align-items-center">
				<?php if(kanews_get_option('google-news-link') != ''): $news_text = (kanews_get_option('google-news-text') != '' ) ? kanews_get_option('google-news-text')  : esc_html__( 'Abone Ol', 'kanews' );  ?>
					<div class="google-news">
						<span><?php echo $news_text; ?></span>
						<a target="_blank" rel="nofollow noopener" title="<?php esc_html_e( 'Google News ile Abone Ol', 'kanews' ); ?>" href="<?php echo kanews_get_option('google-news-link'); ?>" class="google-news-link"></a>
					</div>
				<?php endif; ?>
				<?php if(get_post_meta( $pid, 'post_text_to_speech', true ) != ''): ?>
					<a href="#" data-toggle="kanews-modal-speech" class="open-speech kanews-label d-flex align-items-center"><i class="icon-mic icon-2x"></i> <?php esc_html_e( 'Sesli Dinle', 'kanews' ); ?></a>
					<div id="kanews-modal-speech" class="kanews-modal kanews-modal-speech align-items-center"><div data-toggle="kanews-modal-speech" class="kanews-modal-close"></div>
					<div class="kanews-modal-content"><div class="kanews-modal-title"><?php esc_html_e( 'Sesli Dinle', 'kanews' ); ?></div><div data-toggle="kanews-modal-speech" class="kanews-modal-close-btn"><i class="icon-close"></i></div>
					<div class="kanews-modal-content-inner"><audio id="text-to-speech-audio" controls>
							<source src="<?php echo wp_get_attachment_url(get_post_meta( $pid, 'post_text_to_speech', true )); ?>" type="audio/wav">
						</audio></div></div></div>

				<?php endif; ?>
			</div>
			<div class="kanews-article-action-right col-12 col-lg-auto">
				<div class="d-flex align-items-center flex-wrap">
					<?php echo kanews_add_bookmark($pid); ?>
					<?php if($single_options['post-assets'] == 'on' ): ?>
						<div class="kanews-article-assets">
							<ul class="d-flex">
								<li><a title="<?php esc_html_e( 'Yorum Yap', 'kanews' ); ?>" href="#respond"><i class="icon-comment"></i></a></li>
								<li><a title="<?php esc_html_e( 'Yazıyı Büyült', 'kanews' ); ?>" class="increase-text" href="javascript:void(0);">A+</a></li>
								<li><a title="<?php esc_html_e( 'Yazıyı Küçült', 'kanews' ); ?>" class="decrease-text" href="javascript:void(0);">A-</a></li>
							</ul>
						</div>
					<?php elseif($single_options['post-assets'] != 'off' && $default_options['post-assets'] != false  ): ?>
						<div class="kanews-article-assets">
							<ul class="d-flex">
								<li><a title="<?php esc_html_e( 'Yorum Yap', 'kanews' ); ?>" href="#respond"><i class="icon-comment"></i></a></li>
								<li><a title="<?php esc_html_e( 'Yazıyı Büyült', 'kanews' ); ?>" class="increase-text" href="javascript:void(0);">A+</a></li>
								<li><a title="<?php esc_html_e( 'Yazıyı Küçült', 'kanews' ); ?>" class="decrease-text" href="javascript:void(0);">A-</a></li>
							</ul>
						</div>
					<?php endif; ?>
					<?php if($single_options['post-share'] == 'on' ): ?>
						<?php kanews_post_share($pid);?>
						<?php kanews_post_share_2($pid);?>
					<?php elseif($single_options['post-share'] != 'off' && $default_options['post-share'] != false  ): ?>
						<?php kanews_post_share($pid);?>
						<?php kanews_post_share_2($pid);?>
					<?php endif; ?>
					<?php if(has_post_format( 'video', $pid )):
						if($default_options['post-like'] != false && $single_options['post-like'] != 'off' )
						echo get_simple_likes_button( $pid);
					endif; ?>
				</div>
			</div>
		</div>
	</div>
	
<?php }

/*-----------------------------------------------------------------------------------*/
# List Comments
/*-----------------------------------------------------------------------------------*/
function pressfore_comment_time_output($date, $d, $comment){
	return sprintf( _x( '%s önce', '%s = human-readable time difference', 'kanews' ), human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) ) );
}
add_filter('get_comment_date', 'pressfore_comment_time_output', 10, 3);
if (!function_exists('kanews_list_comments')) :
    function kanews_list_comments($comment, $args, $depth)
    {
			$GLOBALS['comment'] = $comment;
			switch ($comment->comment_type) :
					case 'pingback' :
					case 'trackback' :
					default :
						kanews_get_comment($comment, $args, $depth);
						break;
			endswitch;
    }
endif;

function getProtectedValue($obj, $name) {
  $array = (array)$obj;
  $prefix = chr(0).'*'.chr(0);
  return $array[$prefix.$name];
}
function kanews_get_comment($comment, $args, $depth) {
	?>
	<li <?php comment_class(); ?>  id="comment-<?php comment_ID(); ?>" data-id="<?php comment_ID(); ?>">
		<div class="site-comment-post">
				<div class="comment-author-avatar">
					<?php echo kanews_user_avatar($comment->user_id, 40); ?>
				</div>
				<div class="comment-content vcard" itemtype="http://schema.org/Comment" itemscope="itemscope" itemprop="comment">
					<div class="comment-meta">
						<span class="comment-author vcard">
							<?php 
								$comment_url = $comment->comment_author_url;
								$comment_author = get_comment_author();
								if ($comment_url != '') {
									echo '<a itemprop="author" class="fn" href="'.$comment_url.'">'.$comment_author.'</a>';
								}
								else {
									echo '<cite itemprop="author" class="fn">'.$comment_author.'</cite>';
								}
								echo KANEWS_INSIGHTS::user_badge($comment->user_id);
								echo user_badge($comment->user_id);
								
							?>
						</span>
						<span  class="comment-date"> 
							<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
								<?php echo get_comment_date(); ?>
							</a>
						</span>
					</div>
					<div class="comment-text" itemprop="text">
						<?php if ('0' == $comment->comment_approved) : ?>
							<p class="comment-awaiting-moderation"><?php _e(
								'Yorumunuz editörümüz tarafından incelendikten sonra yayına alınacaktır.',
								'kanews'
							); ?></p>
						<?php endif; ?>
						<?php comment_text(); ?>
					</div>
					<div class="comment-action">
						<?php echo get_simple_likes_button( get_comment_ID(), 1 ); comment_reply_link( array_merge($args, array(
							'reply_text' => __('Yanıtla', 'kanews'),
							'respond_id' => 'respond',    
							'depth'      => $depth,
							'max_depth'  => $args['max_depth']
							)
						)); ?>
						<?php edit_comment_link(__('Düzenle', 'kanews'), '', '') ?>
					</div>

					<?php if($args['has_children'] == 1): ?>
						<div class="comment-show-more"><a href="javascript:void(0);" class="kanews-comment-show-more color-info"><i class="icon-caret icon-180deg"></i> <span><?php echo kanews_translate('show-text', esc_html__( 'Yanıtları Göster', 'kanews' )); ?></span> <?php echo "( ". child_comment_counter($comment->comment_ID) . " )"; ?></a></div>
					<?php endif; ?>
				</div>
		
		</div>
		</li>
	<?php 
}

function child_comment_counter($id){
	global $wpdb;
	$query = "SELECT COUNT(comment_post_id) AS count FROM `wp_comments` WHERE `comment_approved` = 1 AND `comment_parent` = ".$id;
	$children = $wpdb->get_row($query);
	return $children->count;
}

/*-----------------------------------------------------------------------------------*/
# Cookie Box
/*-----------------------------------------------------------------------------------*/
add_action('kanews_footer', 'kanews_cookie_box');
function kanews_cookie_box() { 
	if(kanews_get_option('privacy-policy') != true)
	return;
	?>
	<div id="kanews-cookie-box">
		<div class="kanews-cookie-box">
		<p><?php echo kanews_translate('privacy-policy-text', esc_html__( 'Bu web sitesinde en iyi deneyimi yaşamanızı sağlamak için çerezler kullanılmaktadır.', 'kanews' )); ?></p>
		<?php if(kanews_get_option('privacy-policy-page')): ?>
		<a href="<?php echo get_page_link(kanews_get_option('privacy-policy-page')); ?>"><?php esc_html_e( 'Gizlilik Politikası', 'kanews' ); ?></a>
		<?php endif; ?>
		</div>
		<a onClick="purecookieDismiss();" class="kanews-btn"><?php esc_html_e( 'Kabul Ediyorum', 'kanews' ); ?></a>
	</div>
<?php }

/*-----------------------------------------------------------------------------------*/
# Page Header
/*-----------------------------------------------------------------------------------*/
if ( ! function_exists( 'kanews_page_header' ) ) {
	function kanews_page_header($pid, $title = '', $class = '') { 
		if(get_post_meta($pid, 'page_header', true) == 'off') 
		return;
		?>
		<div class="kanews-page-header <?php echo $class; ?>">
			<div class="container">
				<div class="row">
					<?php if($title == ''): ?>
					<div class="col"><h1 class="kanews-page-title"><?php the_title(); ?></h1></div>
					<?php else: ?>
					<div class="col"><h1 class="kanews-page-title"><?php echo $title; ?></h1></div>
					<?php endif; ?>
				</div>
			</div>
		</div>
	<?php }
}

