<?php

if ( ! defined( 'ABSPATH' ) ) {
	die();
}

// Register Widget
add_action('widgets_init', 'kanews_widget_category_images');
function kanews_widget_category_images() {
	register_widget('kanews_widget_class_category_images');
}

// Widget Class
class kanews_widget_class_category_images extends WP_Widget {

  // Create
	public function __construct(){
		$widget_ops = array('classname' => 'kanews_widget_category_images kanews-section-flat kanews-section-gutter');
		$control_ops = array('id_base' => 'kanews_widget_category_images');
		parent::__construct('kanews_widget_category_images', ''.KAN_THEME_NAME .' - '.__( "Resimli Kategoriler" , 'kanews' ), $widget_ops, $control_ops );
	}
  
  // Front-end
	public function widget($args, $instance)
	{
		extract($args);
		$title = apply_filters('widget_title', $instance['title'] );
    $style = !empty($instance['style']) ? $instance['style'] : '1';
    $postnotin = !empty($instance['postnotin']) ? $instance['postnotin'] : '';
		$exlude = $postnotin;
		$excludecats = explode(",", $exlude); 
    $cat_cover_color = !isset($instance['cat_cover_color']) ? false : true;
    
    $categories = get_categories( array(
			'orderby' => 'count',
			'order'   => 'ASC'
    ) );
    
    $show = 7;
    $sidebar = explode('-', $args['id']);
		if($sidebar[1] == 'sidebar') {
      $show = 2;
    }elseif($sidebar[1] == 'content') {
      $show = 4;
    }

    $slick_options = [
			'slidesToShow' 		=> $show,
			'infinite' 		=> true,
			'responsive' 			=> [
				[
					'breakpoint' 	 => 992,
					'settings'		 => [
						'slidesToShow' => 3
					]
        ],
				[
					'breakpoint' 	 => 525,
					'settings'		 => [
						'slidesToShow' => 2
					]
        ],
			]
    ];

    $slick_options2 = [
			'slidesToShow' 		=> $show2,
			'infinite' 		=> true,
			'responsive' 			=> [
				[
					'breakpoint' 	 => 992,
					'settings'		 => [
						'slidesToShow' => 3
					]
        ],
				[
					'breakpoint' 	 => 525,
					'settings'		 => [
						'slidesToShow' => 2
					]
        ],
			]
    ];
    
    ?>
    
    <div class="col-12"> 
      <div id="<?php echo $this->id; ?>" class="kanews-section <?php echo $this->widget_options['classname']; ?>">
        <?php echo kanews_widget_title($title); ?>
        <?php if($style == '1'): ?>
        <div class="kanews-slider-5 kanews-slider-global">
          <div class="col-12 no-gutter">
            <div class="kanews-slider-wrapper" data-slick='<?php echo wp_json_encode( $slick_options ); ?>'>
              <?php foreach($categories as $category) {
                foreach($excludecats as $cat) {
                  if($cat == $category->term_id) {
                    $image_id = get_term_meta( $category->term_id, 'category-image-id', true );
                    $image_size = 'kanews-post-6';
                    $image_data = wp_get_attachment_image_src( $image_id, $image_size );
                    $image = $image_data[0];
                    $cat_color = get_term_meta( $category->term_id, '_category_color', true ) ? 'style="background: #'.get_term_meta( $category->term_id, '_category_color', true ).' !important"' : '';
                    if($cat_cover_color == true)
                    $cat_color2 = get_term_meta( $category->term_id, '_category_color', true ) ? 'style="background: linear-gradient(0deg,#'.get_term_meta( $category->term_id, '_category_color', true ).',rgba(0,0,0,.2) 50%) !important"' : '';
                    if ( ! empty( $image ) ) { ?>
                      <div class="kanews-slide-item">
                        <div class="kanews-slide-thumb"><img alt="<?php echo $category->name; ?>" src="<?php echo esc_url( $image ); ?>'" /></div>
                        <a href="<?php echo get_category_link( $category->term_id ); ?>" class="kanews-slide-href"></a>
                        <div class="kanews-slide-category-avatar" <?php echo $cat_color; ?>><?php echo substr($category->name, 0, 1); ?></div>

                        <div class="kanews-slide-overlay" <?php echo $cat_color2; ?>></div>
                        <div class="kanews-slide-content">
                          <h5 class="kanews-slide-headline"><?php echo $category->name; ?></h5>
                        </div>
                  
                      </div>
                    <?php 
                    }
                  }
                }
              } ?>
            </div>
          </div>
        </div>
        <?php else: ?>
        <?php endif; ?>
      </div>
    </div>
  <?php
  }
  
  // Update Form
	public function update($new_instance, $old_instance)
	{
		$instance = $old_instance;

		$instance['title'] = $new_instance['title'];
		$instance['style'] = $new_instance['style'];
		$instance['postnotin'] = $new_instance['postnotin'];
		$instance['cat_cover_color'] = $new_instance['cat_cover_color'];

		return $instance;
	}

  // Back-end
	public function form($instance)
	{
		$defaults = array( 
			'title' => '', 
			'postnotin' => '', 
			'style' => '1', 
			'cat_cover_color' => 'off', 
    );
		$instance = wp_parse_args((array) $instance, $defaults); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Başlık' , 'kanews') ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" type="text" />
    </p>

    <p>
			<label for="<?php echo $this->get_field_id('style'); ?>"><?php _e( 'Genişlik' , 'kanews') ?></label> 
			<select id="<?php echo $this->get_field_id('style'); ?>" name="<?php echo $this->get_field_name('style'); ?>" class="widefat" style="width:100%;">
				<option value='1' <?php if ('1' == $instance['style']) echo 'selected="selected"'; ?>>Görünüm #1</option>
			</select>
		</p> 
    
    <p>
      <label for="<?php echo $this->get_field_id('cat_cover_color'); ?>"><?php _e( 'Kaplamayı Kategori Rengine Göre Yap' , 'kanews') ?></label>
			<input class="checkbox" type="checkbox" <?php checked($instance['cat_cover_color'], 'on'); ?> id="<?php echo $this->get_field_id('cat_cover_color'); ?>" name="<?php echo $this->get_field_name('cat_cover_color'); ?>" /> 
    </p>

    <p>
			<label for="<?php echo $this->get_field_id( 'postnotin' ); ?>"><?php _e( 'Gösterilecek Kategoriler (ID)' , 'geo') ?></label>
			<br><i><?php _e('Kategori idlerini virgül ile ayırarak girin', 'geo'); ?></i>
			<input id="<?php echo $this->get_field_id( 'postnotin' ); ?>" name="<?php echo $this->get_field_name( 'postnotin' ); ?>" value="<?php echo $instance['postnotin']; ?>" class="widefat" type="text" />
		</p>
    
    <div class="kanews-widgets-alert ">Kategorinin gözükmesi için kategori sayfasından kategoriye uygun bir görsel eklemeniz gerekir ve ilgili kategoride yazı bulunması gerekir.</div>

		
	<?php }
}
?>